from PIL import Image
from IPython.display import display
import os


main_path = os.path.join(os.path.dirname(__file__), 'pic')


def b(number=''):
    sklad = {
        "info4":"4.1- В группе учится 22 студента. Ими были получены следующие 100-балльные оценки: 64, 41, 83, 41, 83, 53, 0,\n\
63, 84, 98, 2, 42, 98, 57, 63, 53, 91, 28, 76, 63, 78, 83. Найдите: 1) A – среднюю положительную оценку в группе; 2) M –\n\
медиану положительных оценок в группе; 3) H – среднее гармоническое и G – среднее геометрическое оценок,\n\
которые не менее M; 4) Q – медианную оценку в той части группы, в которой студенты набрали не менее M баллов;\n\
5) N – количество студентов, оценки которых оказались между H и Q (включая границы).\n\
\n\
4.2- мпирическое распределение признаков x и y на генеральной совокупности Ω = {1, 2, . . . , 100} задано\n\
таблицей частот\n\
    y=1 | y=2 | y=4\n\
X=200 | 18  | 13  | 17\n\
X=400 | 13  | 16  | 23\n\
Из Ω случайным образом без возвращения извлекаются 14 элементов. Пусть Х и У - средние значения признаков на выбранных элементах. Требуется найти: 1) математическое ожидание Е(Х); 2) дисперсию Var(Y); 3) коэффициент корреляции р(Χ,Υ).\n\
\n\
4.3- Распределение баллов на экзамене до перепроверки задано таблицей\n\
\n\
Оценка работы |2 |3 |4 |5\n\
Число работ   |80|12|55|56 \n\
\n\
Работы будут перепроверять 7 преподавателей, которые разделили все работы между собой поровну случайным образом. Пусть Х - средний балл (до перепроверки) работ, попавших к одному из преподавателей. Требуется найти: 1) математическое ожидание Е(Х);\n\
2) стандартное отклонение σ(Χ)\n\
\n\
4.4-Следующие 30 чисел это умноженные на 10000 и округленные до ближайшего целого дневные логарифмические\n\
доходности акции компании АВС: -956, 744, 1024,794, 17, -252, -1122, -853, 65, -200, 991, 277, 59, -105, -95,\n\
729, 20, 584, -832, -232, -490, -590, 197, -20, -278, -123, -275, 72, -416, -165. Будем называть их преобразованными\n\
доходностями (ПД). Финансовый аналитик Глеб предполагает, что преобразованные доходности (как и исходные) приближенно\n\
распределены по нормальному закону. Чтобы проверить свое предположение Глеб нашел нижнюю квартиль 1 и верхнюю квартиль\n\
Н нормального распределения (м, о²), для которого и это среднее арифметическое ПД, а о - эмпирическое стандартное отклонение\n\
ПД. Затем Глеб подсчитал количество ПД, попавших в интервал от 1 до Н (надеясь, что в этот интервал попадет половина ПД).\n\
Результат этого вычисления показался ему недостаточно убедительным. Чтобы окончательно развеять сомнения относительно нормальности\n\
ПД, Глеб построил на одном рисунке графики функций: F(2) и F(x), где F(2) эмпирическая функция распределения ПД, а F(x) функция\n\
распределения (н, о²). В качестве меры совпадения двух графиков Глеб решил использовать расстояние в между функциями (2) и F(2),\n\
которое он вычислил, исходя из определения: d = sup | F(x) - F(2). В ответе укажите результаты вычислений Глеба: 1) среднее арифметическое ПД;\n\
2) эмпирическое стандартное отклонение ПД; 3) квартили L и Н;\n\
4) количество ПД, попавших в интервал от 1 до Н; 5) расстояние между функциями (2) и F(x).\n\
\n\
4.5-Две игральные кости, красная и синяя, подбрасываются до тех пор, пока не выпадет 11 различных\n\
(с учетом цвета) комбинаций очков. Пусть Ri число очков на красной кости, а Вi число очков на синей кости\n\
в комбинации с номером і. Случайные величины Х; задаются соотношениями: Xi = 15Ri -7Bi, i=1,..., 11. Среднее\n\
арифметическое этих величин обозначим X¯ = 1/11 ∑Xi Требуется найти: 1) математическое ожидание Е(Х¯); 2) стандартное отклонение σ(¯Х).\n\
\n\
4.6-В группе Ω учатся 28 студентов, Ω = {1, 2, . . . , 28}. Пусть Х(і) - 100-балльная оценка студента i ∈ Ω. Из группы\n\
Ω случайным образом 6 раз выбирается студент ω ∈ Ω. Повторный выбор допускается. Пусть ωj - студент, полученный после\n\
выбора j = 1, . . . , 6 X(ωj ) - его оценка. Среднюю оценку на случайной выборке обозначим X¯ = 1/6∑X(ωj ) Оценки в группе даны:\n\
95, 12, 0, 3, 63, 64, 0, 63, 100, 96, 54, 79, 0, 98, 71, 68, 95, 97, 89, 78, 79, 89, 100, 67, 0, 63, 80, 64.\n\
Требуется найти: 1) дисперсию Var(Х); 2) центральный момент из μ3(Х).\n\
\n\
4.7-В группе учатся Ω студенты: ω , . . . , 1 ω30. Пусть X и Y – 100-балльные экзаменационные оценки по\n\
математическому анализу и теории вероятностей. Оценки студента ωi обозначаются: xi = X(ωi)  и  yi = Y (ωi),\n\
i = 1, . . . , 30. Все оценки известны: x1 = 73, y1 = 69 x2 = 39, y2 = 43 x3 = 87, y3 = 88 x4 = 60, y4 = 41\n\
x5 = 79, y5 = 95 x6 = 86, y6 = 98 x7 = 47, y7 = 46 x8 = 42, y8 = 58 x9 = 44, y9 = 43 x10 = 66, y10 = 56\n\
x11 = 47, y11 = 47 x12 = 80, y12 = 85 x13 = 39, y13 = 35 x14 = 73, y14 = 65 x15 = 62, y15 = 77\n\
x16 = 44, y16 = 55 x17 = 44, y17 = 60 x18 = 56, y18 = 43 x19 = 39, y19 = 44 x20 = 86, y20 = 64\n\
x21 = 40, y21 = 39 x22 = 84, y22 = 82 x23 = 74, y23 = 56 x24 = 73, y24 = 68 x25 = 51, y25 = 34\n\
x26 = 38, y26 = 52 x27 = 65, y27 = 65 x28 = 57, y28 = 53 x29 = 33, y29 = 50 x30 = 72, y30 = 94\n\
Требуется найти следующие условные эмпирические характеристики: 1) ковариацию X и Y\n\
при условии, что одновременно X ⩾ 50 и Y ⩾ 50 коэффициент корреляции X и Y при том же условии\n\
\n\
4.8-Поток Ω состоит k из групп: Ω , . . . , 1 Ωk, k = 5. На потоке учатся n = n1+. . . +nk студентов, где ni–\n\
число студентов в группе Ωi i = 1, . . . , k . Пусть X(ω)– 100-балльная оценка студента ω ∈ Ω. Далее\n\
используются следующие обозначения: X¯i– среднее значение, σi– (эмпирическое) стандартное отклонение\n\
признака X на группе Ωi . Дано: n1 = 22 n2 = 29 n3 = 28 n4 = 25 n5 = 20 x1 = 74 x2 = 73 x3 = 72 x4 = 79 x\n\
5 = 80 σ1 = 9 σ2 = 4 σ3 = 7 σ4 = 3 σ5 = 8. Требуется найти: 1) среднее значение на потоке\n\
; 2) (эмпирическое) стандартное отклонение на потоке ."
        ,
"info5":"5.1-Пусть х = (x1, ..., х25) - реализация случайной выборки Х (Х1,..., Х25) из нормального распределения\n\
N(Hx; 0,82), а ў = (91, ..., У35) реализация случайной выборки Y = (Y1,..., Ү35) из нормального распределения\n\
N(Hy; 1,42). Известно, что Х и Ў независимы. Проверяется гипотеза Но : Hz Ну против альтернативной гипотезы Н1 : 4х > Ну.\n\
При уровне значимости а применяется критерий с критической областью {Z> A}, где статистика критерия Z = Z(X, Y) это нормированная\n\
разность Х — Ў, А = Aa Соответствующее критическое множество имеет вид Ка = (Aa; ∞). 1) Найдите значение статистики критерия 7 набл.\n\
Z(х,у). 2) Найдите Р-значение критерия. 3) Найдите критическое значение А, критическое множество Ка и проверьте гипотезу Но при а = 0,03.\n\
4) Найдите мощность критерия W в случае 4x — Hy = 0,6 иа = = 0,03. ИсÃоÄнÜе Äанные: π = (4,837; 2,78; 4,868; 5,183; 2,87; 1,781; 2,421; 2,683;\n\
2,7; 3,764; 2,697; 3,572; 5,147; 4,114; 5,962; 3,183; 3,25; 5,03; 3,894; 4,279; 3,05; 4,855; 4,243; 5,05; 4,536); y = (3,539; 5,746; 2,145; 3,284; 4,602;\n\
3,135; 3,417; 3,694; 0,047; 4,838; 2,735; 4,183; 4,738; 2,781; 4,129; 4,695; 4,016; 3,517; 4,747; 1,872; 5,439; 0,861; 2,821; 4,437; 4,006; 7,154; 4,244;\n\
4,083; 5,911; 2,052; 4,124; 3,738; 4,555; 1,084; 3,996).\n\
\n\
5.2-Пусть x = (x1,…, x20) реализация случайной выборки Х = (Х1,..., Х20) из нормального распределения\n\
N(μ; σ2 ). Проверяется на уровне значимости а = 0,04 основная гипотеза Но: м = 1,45 против альтернативной гипотезы\n\
Н₁: µ ≠ 1,45 с критическим множеством вида Ка =(-∞,-A) U (A,+00).\n\
1)Найдите значение статистики критерия t = T = T( ) набл. x⃗. 2) Найдите границу А критического множества.\n\
3) Найдите Р-значение критерия и сделайте выводы. 4)\n\
Найдите мощность W критерия для H1: μ = 1,34. Исходные данные:\n\
2 = (1,494; 0,274; 10,106; 1,165; 1,411; -0,809; 0,617; 4,121; 6,242; -3,752; 0,98; 0,884; 6,619;\n\
1,781; 6,055; -3,969; 1,481; 4,778; -4,171; 1,672).\n\
\n\
5.3-Пусть x⃗ = (x1,…, x20)– реализация случайной выборки X = ( X1,…, X20)из нормального распределения N(μx; 0,9^2 ), а\n\
y⃗ = (y1,…, y30)– реализация случайной выборки Y = ( y1,…,y30 ) из нормального распределения N(μy; 1,6^2 ). Известно, что X⃗ и\n\
Y⃗ независимы. Проверяется гипотеза H0: μx = μy против альтернативной гипотезы H1: μx > μy. При уровне значимости α\n\
применяется критерий с критической областью {Z > A}, где статистика критерия Z = Z(X⃗, Y⃗) – это нормированная разность X¯ − Y¯ A = Aα\n\
, – зависящее от критическое значение. Соответствующее критическое множество имеет вид Kα = (Aα; ∞). 1)\n\
Найдите значение статистики критерия Zнабл = Z( x, y) . 2) Найдите P-значение критерия. 3) Найдите критическое значение A,\n\
критическое множество Kα и проверьте гипотезу при . 4) Найдите мощность критерия W в случае μx − μy = 1,0 и α = 0,04\n\
. Исходные данные: x=(6,029; 4,203; 3,765; 4,97; 4,137; 4,027; 2,698; 5,84; 4,395; 3,972; 4,64; 3,522; 2,874; 3,886; 3,458;\n\
4,552; 3,553; 3,99; 4,962; 6,457); y=(5,16; 1,45; 1,967; 4,235; 2,802; 5,889; 4,942; 4,955; 2,468; 2,462; 3,003; 4,037; 2,095; 3,673; 5,177;\n\
4,882; 6,149; 7,272; 2,021; 3,916; 2,878; 3,748; 1,986; 6,312; 3,518; 3,856; 4,557; 3,576; 2,487; 3,641).\n\
\n\
5.4-Для трех групп финансовых показателей А, В, С проверяется гипотеза о совпадении ожидаемых значений показателей.\n\
Предполагается, что все показатели Хіj независимы и распределены по нормальному закону N(μj, σ )2 с одинаковой неизвестной\n\
дисперсией Var(X₁₁) = 0², причем для каждой группы (E(Xij ) = μj, j = 1, 2, 3. 1) По данным значениям (файл ds5.9.8.csv) найдите\n\
межгрупповую и среднюю групповую дисперсии. 2) Найдите 91% доверительные интервалы для ожидаемых значений показателей μj, j = 1, 2, 3.\n\
3) Найдите значение статистики критерия f0 = Fнабл., критическое множество Ка и на 3% уровне значимости проверьте гипотезу о совпадении\n\
ожидаемых значений показателей, μ1 = μ2 = μ3. 4) Найдите Р-значение критерия и сделайте выводы\n\
\n\
5.5-Для трех групп финансовых показателей A: (X1; . . . ; X35), B:(Y1; . . . ; Y29) , C:(Z1; . . . ;Z31) , которые по предположению независимы\n\
и распределены, соответственно, по трем нормальным законам N(μx, σ2 ) N(μy, σ2 ) N(μz, σ2 ) (с одинаковой неизвестной дисперсией )\n\
на уровне значимости α = 0,01 с помощью F-критерия (Фишера) проверяется гипотеза H0: μx = μy = μz о совпадении ожидаемых\n\
значений показателей. Конкретные значения всех показателей указаны ниже. 1) По данным значениям показателей найдите межгрупповую\n\
дисперсию. 2) По этим же данным найдите среднюю групповую дисперсию. 3) Найдите значение статистики F-критерия, критическое\n\
множество Kα и проверьте гипотезу H0. 4) Найдите P-значение критерия и сделайте выводы.\n\
Значения показателей группы A: (-2,63; 2,812; 3,354; -1,754; 3,732; 0,411; 4,594; 8,272; 0,437; 10,205; 5,254; -0,846; 0,729; 3,799; 1,174; 2,885;\n\
1,489; -3,153; 2,788; 1,361; -0,556; 3,637; 0,484; -3,043; 0,471; 1,513; 4,164; 2,327; 3,715; 1,989; 3,666; 5,35; 4,509; 7,537; 0,258). Значения\n\
показателей группы B: (0,024; -1,306; 2,986; 2,237; 3,289; 5,557; 1,174; 2,651; 3,268; 2,492; 2,516; 0,924; 5,502; 4,909; -0,901; -0,13; 0,28; -1,594;\n\
1,728; 1,737; 1,491; 1,43; -1,218; 2,952; -0,516; 2,881; 1,591; 2,129; 0,819). Значения показателей группы C: (-0,638; 2,623; 6,466; -1,684; 4,656;\n\
-0,655; 2,152; 1,103; 0,503; 4,185; 0,627; -0,555; -0,98; 0,852; -1,945; 5,233; 3,124; -4,2; 0,958; 4,156; 0,936; -1,321; 0,573; 0,164; 1,11; 5,099;\n\
0,084; 0,934; 0,941; -1,156; -2,437).\n\
\n\
5.6-Для трех групп финансовых показателей A: (X1; . . . ; X21), B: (Y1; . . . ; Y29) , C: (Z1; . . . ;Z19), которые по\n\
предположению независимы и распределены, соответственно, по трем нормальным законам N(μx, σ2 ),N(μy, σ2 ) , N(μz, σ2 )\n\
(с одинаковой неизвестной дисперсией σ2) на уровне значимости α = 0,02 с помощью F-критерия (Фишера)\n\
проверяется гипотеза H0 : μx = μy = μz  о совпадении ожидаемых значений показателей. Конкретные значения всех\n\
показателей указаны ниже. 1) По данным значениям показателей найдите межгрупповую дисперсию. 2) По этим же\n\
данным найдите среднюю групповую дисперсию. 3) Найдите значение статистики F-критерия, критическое множество\n\
Kα и проверьте гипотезу H0. 4) Найдите -значение критерия и сделайте выводы.\n\
Значения показателей группы A: (2,468; -0,424; 4,698; 0,896; -0,203; -4,026; 2,256; -0,445; -1,601; -1,691; -0,27; 0,763;\n\
3,397; 4,01; -0,56; -2,392; -1,849; 1,166; 2,48; 5,298; 0,907). Значения показателей группы B: (0,322; 0,937; -3,299; 1,335;\n\
0,855; 0,409; 2,306; 2,757; 1,255; 1,974; 0,201; 1,693; -3,51; -0,666; 1,84; -1,726; 1,234; 0,703; 3,853; 3,715; 2,912; -1,623;\n\
2,144; 0,257; 1,12; 0,862; -0,397; 4,784; 3,922). Значения показателей группы C: (-2,725; 5,806; 3,927; 0,172; 5,126; 2,058;\n\
3,098; 3,966; 0,403; 1,679; 0,082; 2,417; -0,679; -0,949; -1,268; -1,395; -2,071; -0,963; 7,509)."
    ,
    "info6":"6.1-По содержащейся в файле ds6.4.12.csv реализации случайной выборки из двумерного нормального\n\
распределенияN ((E(X); E(Y )); || Var(X)   Cov(X,Y)||)= N ((2; 2); ||σ^2  ρσ^2||)\n\
                            || Cov(X,Y) Var(Y)  ||)             ||ρσ^2 σ^2 ||)\n\
с неизвестными параметрами ρ ∈ (−1; 1) и σ > 0 \n\
и : 1) запишите логарифм функции правдоподобия,lnL(ρ, σ) ; 2) найдите оценки максимального\n\
правдободобия ρˆ и σˆ.\n\
\n\
6.2-Пусть (x1, y1); . . . ;(x36, y36)– реализация случайной выборки (X1, Y1); . . . ;(X36, Y36) из двумерного\n\
нормального распределения N(μx; μy; (σ^2)x ;(σ^2)y  ; ρ). Используя векторы x⃗ = (x1; . . . ; x36) и y⃗ = (y1; . . . ; y36) , постройте\n\
асимптотический 0,73-доверительный интервал (θˆ1, θˆ2)\n\
для коэффициента корреляции ρ. В ответе укажите: 1)\n\
выборочный коэффициент корреляции ρˆ 2) верхнюю границу θˆ2 построенного доверительного интервала для ρ.\n\
Исходные данные: x⃗= (-1,377; -0,664; 0,544; -0,259; -0,162; -0,065; -1,324; 0,561; 0,382; 1,482; -1,113; -0,68; 0,536; -0,541;\n\
-1,348; -0,287; 0,964; 1,353; -0,095; -0,008; -0,505; 2,807; 1,258; -0,517; 2,763; 0,285; -0,836; 0,891; 0,785; 0,811; 0,08; -0,09;\n\
1,637; 2,165; 0,911; -2,165), y⃗= (-1,466; -0,554; 0,575; 0,284; -0,779; 0,179; -1,809; 0,707; 0,108; 1,174; -1,672; -0,654;\n\
-0,187; -0,643; -0,995; 0,489; 0,69; 1,612; 0,176; 0,275; -0,217; 2,311; 1,107; -0,395; 2,467; 0,362; -0,978; 0,975; 0,439; 0,765;\n\
0,154; -0,308; 1,404; 1,674; 0,816; -1,418).\n\
\n\
6.3-Фёдор и Ева исследуют эффективность лекарственного препарата АВС. Фёдор, используя модель Евы, создал компьютерную\n\
программу, вычисляющую по заданным генетическим факторам вероятность (в процентах) успешного применения АВС. Программа\n\
Фёдора накапливает полученные вероятности и в итоге выдает набор частот:n0, n1, . . . , n100 . Например, n75– это число случаев, в\n\
которых программа Фёдора получила вероятность 75%. Обработав 500 образцов генетического материала, Ева нашла значения\n\
факторов и ввела их в программу. В результате был получен следующий набор частот: 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1, 2, 0, 1, 1, 0, 1, 1,\n\
1, 1, 0, 4, 6, 3, 3, 1, 3, 5, 6, 4, 5, 6, 7, 5, 6, 6, 9, 11, 10, 7, 11, 13, 10, 13, 8, 10, 9, 20, 10, 11, 15, 9, 10, 10, 13, 18, 18, 13, 12, 10, 14, 11, 12,\n\
11, 9, 8, 10, 10, 6, 6, 4, 5, 8, 3, 4, 1, 4, 3, 1, 2, 3, 1, 0, 3, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0. Для завершения этапа исследования\n\
необходимо было подобрать распределение, соответствующее полученным частотам. Ева решила использовать распределение на\n\
отрезке [0, 1] с плотностью f(x) = f(x; a, b) = abx^(a−1)(1 − x^a)^b−1и целочисленными параметрами a, b в диапазоне от 1 до 20. В\n\
результате максимизации функции правдоподобия (при указанных ограничениях) Фёдором были получены значения параметров:\n\
a^ = A и b^ = B. Задача: пусть X– случайная величина, распределения на отрезке [0, 1] с плотностью f(x) = f(x; a^, b^) ,F(x)– ее\n\
функция распределения. Требуется найти математическое ожидание E(X) и X0,2 = F (0,2) – квантиль уровня 0,2. Какой смысл\n\
для всей популяции имеют E(X) и X0,2 ? В ответе укажите: 1) значение А ; 2) значение В ; 3) математическое ожидание E(X); 4)\n\
квантиль X0,2 ."
        ,
        "infotest2":"test2:\n\
Фёдор и Ева исследуют эффективность лекарственного препарата АВС. Фёдор, используя модель Евы, создал компьютерную\n\
программу, вычисляющую по заданным генетическим факторам вероятность (в процентах) успешного применения АВС. Программа\n\
Фёдора накапливает полученные вероятности и в итоге выдает набор частот:n0, n1, . . . , n100 . Например, n75– это число случаев, в\n\
которых программа Фёдора получила вероятность 75%. Обработав 500 образцов генетического материала, Ева нашла значения\n\
факторов и ввела их в программу. В результате был получен следующий набор частот: 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1, 2, 0, 1, 1, 0, 1, 1,\n\
1, 1, 0, 4, 6, 3, 3, 1, 3, 5, 6, 4, 5, 6, 7, 5, 6, 6, 9, 11, 10, 7, 11, 13, 10, 13, 8, 10, 9, 20, 10, 11, 15, 9, 10, 10, 13, 18, 18, 13, 12, 10, 14, 11, 12,\n\
11, 9, 8, 10, 10, 6, 6, 4, 5, 8, 3, 4, 1, 4, 3, 1, 2, 3, 1, 0, 3, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0. Для завершения этапа исследования\n\
необходимо было подобрать распределение, соответствующее полученным частотам. Ева решила использовать распределение на\n\
отрезке [0, 1] с плотностью f(x) = f(x; a, b) = abx^(a−1)(1 − x^a)^b−1и целочисленными параметрами a, b в диапазоне от 1 до 20. В\n\
результате максимизации функции правдоподобия (при указанных ограничениях) Фёдором были получены значения параметров:\n\
a^ = A и b^ = B. Задача: пусть X– случайная величина, распределения на отрезке [0, 1] с плотностью f(x) = f(x; a^, b^) ,F(x)– ее\n\
функция распределения. Требуется найти математическое ожидание E(X) и X0,2 = F (0,2) – квантиль уровня 0,2. Какой смысл\n\
для всей популяции имеют E(X) и X0,2 ? В ответе укажите: 1) значение А ; 2) значение В ; 3) математическое ожидание E(X); 4)\n\
квантиль X0,2 .\n\
#------------------------------------------------------------------------------------------------------------------------------------------------------------\n\
Следующие 28 чисел это умноженные на 10000 и округленные до ближайшего целого дневные логарифмические доходности акции компании АВС:\n\
-9, 9, 138, 145, 186, 78, 34, 37, -19, 68, 82, 158, 96, 189, 24, 84, 99, 125, -39, 26, 62, 91, 239, 211, 2, 129, 2, 16.\n\
Будем называть их преобразованными доходностями (ПД). Финансовый аналитик Глеб предполагает, что преобразованные доходности (\n\
как и исходные) приближенно распределены по нормальному закону. Чтобы проверить свое предположение Глеб нашел нижнюю квартиль\n\
1 и верхнюю квартиль Н нормального распределения (р.а²), для которого и это среднее арифметическое ПД, а эмпирическое стандартное\n\
отклонение ПД. Затем Глеб подсчитал количество ПД, попавших в интервал от 1 до Н (надеясь, что в этот интервал попадет половина ПД).\n\
Результат этого вычисления показался ему недостаточно убедительным. Чтобы окончательно развеять сомнения относительно нормальности ПД,\n\
Глеб построил на одном рисунке графики функций F(z) и F(z), где (г)- эмпирическая функция распределения ПД, а F() функция распределения\n\
(4, 2). В качестве меры совпадения двух графиков Глеб решил использовать расстояние в между функциями F(z) и F(z), которое он вычислил,\n\
исходя из определения: sup|F(z) F(z). В ответе укажите результаты вычислений Глеба: 1) среднее арифметическое ПД.\n\
2) эмпирическое стандартное отклонение ПД; 3) квартили и н;\n\
4) количество ПД, попавших в интервал от 1 до Н; 5) расстояние между функциями F(x) и F(x)\n\
\n\
#------------------------------------------------------------------------------------------------------------------------------------------------------------\n\
В группе Я учатся студенты: 1,..., 30. Пусть Х и У 100-балльные экзаменационные оценки по математическому анализу и теории вероятностей.\n\
Оценки студента шу обозначаются: х = Х(ш) и у = Y(). i 1,..., 30. Все оценки известны: 2171,3171,2252, 258, 2372, y381,2487,492,581,9581,\n\
26100,3694,2790,9796, 2854,3846, 2954, 3/960, 21058, 3/1062, 21156, 9/11 149, 1270, 391260, 21393, 3/1386, 21446, 91448, 21556,91561, 21659,\n\
31652, 1742, 91740, 21860, 3/1860, 1933, 2/1937, 2083, 920 92, 22150,92157, 222 93, 92293, 223 41,923 42, 202455, 192464, 22560, 1/2559, 237,\n\
2030, 22771,92771, 22842, 92844,285,92982, 230 = 39, узо = 39. Требуется найти следующие условные эмпирические характеристики:\n\
1) ковариацию Х и У при условии, что одновременно Х≥ 50 и У≥ 50; 2) коэффициент корреляции Х и У при том же условии\n\
\n\
Поток Ω состоит из k групп. Ω1,...,Ωk=3. На потоке учатся в n=n1+... +nk студентов, где ni - число студентов в группе Ωi, i=1,...,k. Пусть Х(w) 100-балльная оценка студента X є Ω. Далее\n\
используются следующие обозначения: xi, среднее значение, т. (эмпирическое) стандартное отклонение признака Х на группе Ωi. Дано: п₁ = 24, па = 26, 330, 2= 70 = 76.2 = 77.0=400 8.\n\
Требуется найти: 1) среднее значение Х на потоке Ω. 2) (эмпирическое) стандартное отклонение Х на потоке Ω"
        ,
        "infotest3":"test3:Пусть (x1,y1);...;(x31,y31)– реализация случайной выборки (X1,Y1);...;(X31,Y31)\n\
из двумерного нормального распределения N(μx;μy;σ2x;σ2y;ρ).\n\
Используя векторы x⃗ =(x1;...;x31) и y⃗ =(y1;...;y31), постройте асимптотический 0,93-\n\
доверительный интервал (θˆ1;θˆ2) для коэффициента корреляции ρ. В ответе укажите: 1) выборочный коэффициент корреляции ρˆ;\n\
2) верхнюю границу θˆ2 построенного доверительного интервала для ρ.Исходные данные: x⃗ \n\
= (-0,616; -0,238; 0,173; -0,255; 0,531; 0,718; -0,161; 0,371; -1,014; -0,413; -1,571; 0,485; 0,486; 0,688; -0,944; 0,155; 0,003; 0,111; 0,752; 0,783; -0,102; -0,74; -2,097; 1,349; -0,044; -0,617; -0,782; -0,873; -0,995; -1,256; -0,596),\n\
y⃗ = (-1,34; -0,25; 0,101; -0,626; -0,088; 0,539; -0,451; 0,233; -1,186; -0,423; -1,329; 0,231; 0,209; 0,638; -0,274; -0,491; -0,319; 0,294; 0,895; 1,164; -0,57; -1,078; -1,526; 1,491; 0,182; -0,31; -1,001; -0,969; -0,918; -0,904; -0,595).\n\
\n\
#------------------------------------------------------------------------------------------------------------------------------------------------------------\n\
Глеб и Анна исследуют эффективность лекарственного препарата АВС. Глеб, используя модель Анны, создал компьютерную программу, вычисляющую по заданным генетическим факторам\n\
вероятность (в процентах) успешного применения АВС. Программа Глеба накапливает полученные вероятности и в итоге выдает набор частот: n0,n1,...,n100. Например, n75\n\
– это число случаев, в которых программа Глеба получила вероятность 75%. Обработав 1000 образцов генетического материала, Анна нашла значения факторов и ввела их в программу.\n\
В результате был получен следующий набор частот: 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,\n\
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, 0, 1, 1, 3, 4, 4, 5, 4, 6, 6, 11, 9, 19, 23, 25, 33, 36, 36, 46, 46, 49, 58, 90, 76, 66, 69, 75, 68, 44,\n\
39, 21, 16, 5, 2, 1, 0, 0, 0. Для завершения этапа исследования необходимо было подобрать распределение, соответствующее полученным частотам. Анна решила использовать распределение на отрезке [0,1]\n\
с плотностью f(x)=f(x;a,b)=abxa−1(1−xa)b−1 и целочисленными параметрами a,b\n\
в диапазоне от 1 до 20. В результате максимизации функции правдоподобия (при указанных ограничениях) Глебом были получены значения параметров: a^=Aи b^=B\n\
. Задача: пусть X – случайная величина, распределения на отрезке [0,1] с плотностью f(x)=f(x;a^,b^), F(x)\n\
– ее функция распределения. Требуется найти математическое ожидание E(X) и X0, 2=F−1(0,2)\n\
– квантиль уровня 0,2. Какой смысл для всей популяции имеют E(X)и X0, 2\n\
? В ответе укажите: 1) значение A; 2) значение B; 3) математическое ожидание E(X); 4) квантиль X0, 2."
        ,
        "infotest4":"test4:\n\
Пусть x⃗ =(x1,…,x30)\n\
– реализация случайной выборки X⃗ =(X1,…,X30) из нормального распределения N(μ;3,42)\n\
. Проверяется на уровне значимости α=0,01 основная гипотеза H0:μ=1,29\n\
против альтернативной гипотезы H1:μ≠1,29 с критическим множеством вида Kα=(−∞,−A)∪(A,+∞)\n\
. 1) Найдите значение статистики критерия Zнабл.=Z(x⃗ ). 2) Найдите границу А критического множества. 3) Найдите P\n\
-значение критерия и сделайте выводы. 4) Найдите мощность Wкритерия для H1:μ=1,17.Исходные данные: x⃗ =\n\
(1,416; 0,624; 6,471; 6,256; 1,787; 2,546; -1,758; -5,475; 0,077; 1,792; 5,443; 5,348; -0,057; 0,232;\n\
-2,305; -3,568; -4,541; 7,893; -0,473; -0,229; -3,0; 3,903; -4,227; 0,537; -1,785; 2,575; -0,477; -2,754; 1,164; 2,716).\n\
\n\
#------------------------------------------------------------------------------------------------------------------------------------------------------------\n\
\n\
Пусть x⃗ =(x1,…,x20)– реализация случайной выборки X⃗ =(X1,…,X20)\n\
из нормального распределения N(μ;σ2). Проверяется на уровне значимости α=0,05\n\
основная гипотеза H0:μ=1,10 против альтернативной гипотезы H1:μ≠1,10\n\
с критическим множеством вида Kα=(−∞,−A)∪(A,+∞). 1) Найдите значение статистики критерия t=Tнабл.=T(x⃗ )\n\
. 2) Найдите границу А критического множества. 3) Найдите P-значение критерия и сделайте выводы. 4) Найдите мощность W\n\
критерия для H1:μ=0,91.\n\
Исходные данные: x⃗ =\n\
(1,146; 2,958; -3,325; -0,534; 0,374; 5,293; 0,12; 1,185; 5,148; 5,351; 2,639; 1,47; -1,967; 4,96; 6,057; -0,542; 1,544; -0,243; -1,988; 2,844).\n\
\n\
#------------------------------------------------------------------------------------------------------------------------------------------------------------\n\
\n\
Пусть x⃗ =(x1,…,x30)– реализация случайной выборки X⃗ =(X1,…,X30)\n\
из нормального распределения N(1,18;σ2). Проверяется на уровне значимости α=0,02\n\
гипотеза H0:σ=1,14 против альтернативной гипотезы H1:σ≠1,14\n\
с критическим множеством вида Kα=(0;A)∪(B;+∞). 1) Найдите значение статистики критерия χ20.\n\
2) Найдите границы А и В критического множества и проверьте гипотезу H0. 3) Найдите P\n\
-значение критерия. 4) Найдите вероятность ошибки второго рода β для σ1=1,24. Исходные данные: x⃗ =\n\
(0,889; 1,514; 2,846; 2,811; 0,84; 0,945; 0,02; -0,441; -0,796; 3,739; 0,688; 0,777; -0,233; 2,284; -0,681; 1,056; 0,21;\n\
1,8; 0,687; -0,144; 1,285; 1,851; 1,402; 1,695; 0,533; 0,87; 0,486; 0,874; 0,312; -0,821).\n\
\n\
#------------------------------------------------------------------------------------------------------------------------------------------------------------\n\
\n\
Пусть x⃗ =(x1,…,x30)– реализация случайной выборки X⃗ =(X1,…,X30)\n\
из нормального распределения N(μ;σ2). Проверяется на уровне значимости α=0,02гипотеза H0:σ=1,14\n\
против альтернативной гипотезы H1:σ≠1,14с критическим множеством вида Kα=(0;A)∪(B;+∞).\n\
1) Найдите значение статистики критерия χ2. 2) Найдите границы А и В критического множества и проверьте гипотезу H0.\n\
3) Найдите P-значение критерия. 4) Найдите вероятность ошибки второго рода βдля σ1=1,24.\n\
Исходные данные: x⃗ =\n\
(0,889; 1,514; 2,846; 2,811; 0,84; 0,945; 0,02; -0,441; -0,796; 3,739; 0,688; 0,777; -0,233; 2,284; -0,681; 1,056;\n\
0,21; 1,8; 0,687; -0,144; 1,285; 1,851; 1,402; 1,695; 0,533; 0,87; 0,486; 0,874; 0,312; -0,821).\n\
\n\
#------------------------------------------------------------------------------------------------------------------------------------------------------------\n\
\n\
Пусть x⃗ =(x1,…,x25)– реализация случайной выборки X⃗ =(X1,…,X25)из нормального распределения N(μx;0,72)\n\
, а y⃗ =(y1,…,y30) – реализация случайной выборки Y⃗ =(Y1,…,Y30)из нормального распределения N(μy;1,42).\n\
Известно, что X⃗ и Y⃗ независимы. Проверяется гипотеза H0:μx=μy против альтернативной гипотезы H1:μx>μy.\n\
При уровне значимости α применяется критерий с критической областью {Z>A}, где статистика критерия Z=Z(X⃗ ,Y⃗ )\n\
– это нормированная разность X¯−Y¯, A=Aα – зависящее от α критическое значение. Соответствующее критическое множество имеет вид Kα=(Aα;∞).\n\
1) Найдите значение статистики критерия Zнабл.=Z(x⃗ ,y⃗ ).\n\
2) Найдите P-значение критерия. 3) Найдите критическое значение A, критическое множество Kα и проверьте гипотезу H0при α=0,02.\n\
4) Найдите мощность критерия W в случае μx−μy=0,1 и α=0,02.\n\
Исходные данные: x⃗ =\n\
(3,842; 3,374; 4,18; 4,5; 4,247; 4,412; 3,756; 3,946; 3,729; 3,948; 3,631; 2,992; 4,324; 3,919; 3,059; 4,524; 3,565; 4,236; 4,71; 4,29; 4,998; 3,336; 4,482; 3,721; 3,59); y⃗ =\n\
(3,19; 3,564; 4,079; 2,369; 5,261; 4,652; 1,849; 6,084; 6,654; 5,65; 3,748; 2,501; 5,476; 3,436; 5,711; 4,292; 5,367; 4,499; 4,989; 4,015; 6,5; 4,178; 4,563; 6,636; 2,113; 2,221; 5,357; 2,358; 6,721; 3,421).\n\
\n\
\n\
#------------------------------------------------------------------------------------------------------------------------------------------------------------\n\
\n\
Для трех групп финансовых показателей A: (X1;...;X27), B: (Y1;...;Y33), C: (Z1;...;Z39),\n\
которые по предположению независимы и распределены, соответственно, по трем нормальным законам N(μx,σ2), N(μy,σ2), N(μz,σ2)\n\
(с одинаковой неизвестной дисперсией σ2) на уровне значимости α=0,01 с помощью F-критерия (Фишера) проверяется гипотеза H0:μx=μy=μz\n\
о совпадении ожидаемых значений показателей. Конкретные значения всех показателей указаны ниже. 1) По данным значениям показателей найдите межгрупповую дисперсию.\n\
2) По этим же данным найдите среднюю групповую дисперсию. 3) Найдите значение статистики F-критерия, критическое множество Kα и проверьте гипотезу H0.\n\
4) Найдите P -значение критерия и сделайте выводы.Значения показателей группы A:\n\
(0,616; 1,046; 2,575; -0,344; 2,339; -0,68; 3,739; 2,251; -1,252; 3,536; -0,491; 5,556; 4,856; -1,68; 2,33; 1,345; 2,829; 2,539; 3,304; 3,497; 0,211; 3,563;\n\
0,94; 3,642; 1,956; 3,919; 3,568). Значения показателей группы B: (2,834; 1,504; -0,678; 5,619; 0,97; 1,617; 3,768; -1,309; 3,343; -1,778; -0,854; 1,04; 2,83;\n\
-2,335; 4,853; 5,6; 4,341; 4,362; 3,52; 1,151; -0,621; -2,88; 1,697; 1,753; 0,211; 2,157;1,989; 2,457; 1,399; 1,61; -0,558; 2,132; 2,293). Значения показателей группы\n\
C: (2,398;-2,77; 4,679; 1,924; 0,574; 5,329; 0,699; 4,457; -0,3; 1,682; -1,34; 0,046; -1,096; 1,935; 2,411; 4,134; 5,643; 3,071; 6,526; 4,941; 2,844; -0,43;\n\
-2,066; 0,22; 0,317; -1,923; 1,38; -2,485; 0,111; -0,542; 4,78; 1,93; 0,462; 5,487; -3,547; 2,933; -0,987; -0,21; 3,955)."
        ,
        "import":"import numpy as np\n\
import pandas as pd\n\
import scipy.stats as scs\n\
import mpmath as mp\n\
from fractions import Fraction\n\
from sympy import *\n\
import scipy.integrate as integrate\n\
from scipy.optimize import minimize\n\
import re\n\
from scipy.stats import *\n\
\n\
\n\
def convert(s):\n\
s = s.replace(',', '.').replace(';', ',')\n\
data = map(float, s.split(','))\n\
return list(data)\n\
\n\
def rrstr(x,n): # округление до n знаков после запятой\n\
fmt = '{:.'+str(n)+'f}'\n\
return fmt.format(x).replace('.',',')\n\
\n\
Z = norm()\n\
\n\
def Phi0(x):\n\
return Z.cdf(x) - 1 / 2\n\
\n\
\n\
!pip install pm20_5\n\
!pip install tvims\n\
from pm20_5 import q1,q2,q3,q4,q5,q6\n\
import tvims"
        ,
        "4.1":"В группе учится 22 студента. Ими были получены следующие 100-балльные оценки: 64, 41, 83, 41, 83, 53, 0,\n\
63, 84, 98, 2, 42, 98, 57, 63, 53, 91, 28, 76, 63, 78, 83. Найдите: 1) A – среднюю положительную оценку в группе; 2) M –\n\
медиану положительных оценок в группе; 3) H – среднее гармоническое и G – среднее геометрическое оценок,\n\
которые не менее M; 4) Q – медианную оценку в той части группы, в которой студенты набрали не менее M баллов;\n\
5) N – количество студентов, оценки которых оказались между H и Q (включая границы).\n\
\n\
\n\
\n\
a=np.array([64, 41, 83, 41, 83, 53, 0, 63, 84, 98, 2, 42, 98, 57, 63, 53, 91, 28, 76, 63, 78, 83])\n\
print(a[a > 0].mean())#A\n\
m=np.median(a)\n\
print(m)#M\n\
a2 = a[a >= m]\n\
print(hmean(a2), gmean(a2))#H,G\n\
print(np.median(a2))#Q\n\
a3 = a[a >= hmean(a2)]\n\
print(len(a3[a3 <= np.median(a2)]))#N"
        ,
        "4.2":"Эмпирическое распределение признаков x и y на генеральной совокупности Ω = {1, 2, . . . , 100} задано\n\
таблицей частот\n\
    y=1 | y=2 | y=4\n\
X=200 | 18  | 13  | 17\n\
X=400 | 13  | 16  | 23\n\
Из Ω случайным образом без возвращения извлекаются 14 элементов. Пусть Х и У - средние значения признаков на выбранных элементах. Требуется найти: 1) математическое ожидание Е(Х); 2) дисперсию Var(Y); 3) коэффициент корреляции р(Χ,Υ).\n\
\n\
\n\
vals = [(200, 1)] * 18 + [(200, 2)] * 13 + [(200, 4)] * 17 + \   \n\
[(400, 1)] * 13 + [(400, 2)] * 16 + [(400, 4)] * 23\n\
k = 14\n\
\n\
\n\
vals = np.array(vals)\n\
n = len(vals)\n\
\n\
E = vals.mean(axis=0)[0]\n\
print(E)  #математическое ожидание\n\
\n\
VarY = vals.var(axis=0)[1]\n\
VarY = VarY / k * (n - k) / (n - 1)pow\n\
print(VarY) #  дисперсия\n\
\n\
cov = ((vals[:, 0] * vals[:, 1]).mean() - vals[:, 0].mean() * vals[:, 1].mean()) / k * (n - k) / (n - 1)\n\
VarX = vals.var(axis=0)[0]\n\
VarX = VarX / k * (n - k) / (n - 1)\n\
\n\
ro = cov / (np.sqrt(VarX) * np.sqrt(VarY))\n\
print(ro) # коэффициент корреляции"
        ,
        "4.3":"Распределение баллов на экзамене до перепроверки задано таблицей\n\
\n\
Оценка работы |2 |3 |4 |5\n\
Число работ   |80|12|55|56 \n\
\n\
Работы будут перепроверять 7 преподавателей, которые разделили все работы между собой поровну случайным образом. Пусть Х - средний балл (до перепроверки) работ, попавших к одному из преподавателей. Требуется найти: 1) математическое ожидание Е(Х);\n\
2) стандартное отклонение σ(Χ)\n\
\n\
\n\
vals = [2] * 80 + [3] * 12 + [4] * 55 + [5] * 56\n\
k = 7\n\
\n\
vals = np.array(vals)\n\
n = len(vals)\n\
k = n / k\n\
E = vals.mean()\n\
print(E) # математическое ожидание \n\
\n\
Var = vals.var() / k * (n - k) / (n - 1)\n\
std = np.sqrt(Var)\n\
print(std) # стандартное отклонение"
        ,
        "4.4":"Следующие 38 чисел это умноженные на 10000 и округленные до ближайшего целого дневные логарифмические\n\
доходности акции компании АВС: 157, 1170, 149, -305, 1120, 410, 645, -453, -141, 306, -294, -284, -509, 408, -726, -425, 410, 271, 331, 81, 135, -488, 866,\n\
-561, 302, 240, -211, -328, -192, 573, -34, -125, 720, -916, 572, 547, 37, 482. Будем называть их преобразованными\n\
доходностями (ПД). Финансовый аналитик Глеб предполагает, что преобразованные доходности (как и исходные) приближенно\n\
распределены по нормальному закону. Чтобы проверить свое предположение Глеб нашел нижнюю квартиль 1 и верхнюю квартиль\n\
Н нормального распределения (м, о²), для которого и это среднее арифметическое ПД, а о - эмпирическое стандартное отклонение\n\
ПД. Затем Глеб подсчитал количество ПД, попавших в интервал от 1 до Н (надеясь, что в этот интервал попадет половина ПД).\n\
Результат этого вычисления показался ему недостаточно убедительным. Чтобы окончательно развеять сомнения относительно нормальности\n\
ПД, Глеб построил на одном рисунке графики функций: F(2) и F(x), где F(x) эмпирическая функция распределения ПД, а F(x) функция\n\
распределения (н, о²). В качестве меры совпадения двух графиков Глеб решил использовать расстояние в между функциями (x) и F(x),\n\
которое он вычислил, исходя из определения: d = sup | F(x) - F(x). В ответе укажите результаты вычислений Глеба: 1) среднее арифметическое ПД;\n\
2) эмпирическое стандартное отклонение ПД; 3) квартили L и Н;\n\
4) количество ПД, попавших в интервал от 1 до Н; 5) расстояние между функциями (2) и F(x).\n\
\n\
\n\
vals = np.array([157, 1170, 149, -305, 1120, 410, 645, -453, -141, 306, -294, -284, -509, 408, -726, -425, 410, 271, 331, 81, 135, -488, 866,\n\
-561, 302, 240, -211, -328, -192, 573, -34, -125, 720, -916, 572, 547, 37, 482])\n\
\n\
v_mean = vals.mean()\n\
v_std = vals.std()\n\
print(v_mean)\n\
print(v_std)\n\
\n\
X = norm(v_mean, v_std)\n\
L = X.ppf(0.25)\n\
H = X.ppf(0.75)\n\
print(L, H)\n\
\n\
print(len(vals[(vals >= L) & (vals <= H)])) # колличество ПД, попавших в интервал от L до H\n\
\n\
xsort=sorted(vals)\n\
n=len(xsort)\n\
res_d = float('-inf')\n\
for i in range(len(xsort)):\n\
    maxx=max(abs((i+1)/n-X.cdf(xsort[i])),abs((i)/n-X.cdf(xsort[i])))\n\
    if maxx > res_d:\n\
        res_d = maxx\n\
        d_ind = i\n\
print(res_d)"
        ,
        "4.5":"Две игральные кости, красная и синяя, подбрасываются до тех пор, пока не выпадет 11 различных\n\
(с учетом цвета) комбинаций очков. Пусть Ri число очков на красной кости, а Вi число очков на синей кости\n\
в комбинации с номером і. Случайные величины Х; задаются соотношениями: Xi = 15Ri -7Bi, i=1,..., 11. Среднее\n\
арифметическое этих величин обозначим X¯ = 1/11 ∑Xi Требуется найти: 1) математическое ожидание Е(Х¯); 2) стандартное отклонение σ(¯Х).\n\
\n\
\n\
k = 11\n\
n = 36\n\
\n\
combs = [(r, b) for r in range(1, 7) for b in range(1, 7)]\n\
combs = np.array(combs)\n\
mean, var = combs.mean(axis=0), combs.var(axis=0)\n\
E = 15 * mean[0] - 7 * mean[1]\n\
\n\
Var = 15**2 * var[0] + 7**2 * var[1]\n\
Var = Var / k * (n - k) / (n - 1)\n\
std = np.sqrt(Var)\n\
\n\
E, std#математическое ожидание, стандартное отклонение"
        ,    
        "4.6":"В группе Ω учатся 28 студентов, Ω = {1, 2, . . . , 28}. Пусть Х(і) - 100-балльная оценка студента i ∈ Ω. Из группы\n\
Ω случайным образом 6 раз выбирается студент ω ∈ Ω. Повторный выбор допускается. Пусть ωj - студент, полученный после\n\
выбора j = 1, . . . , 6 X(ωj ) - его оценка. Среднюю оценку на случайной выборке обозначим X¯ = 1/6∑X(ωj ) Оценки в группе даны:\n\
95, 12, 0, 3, 63, 64, 0, 63, 100, 96, 54, 79, 0, 98, 71, 68, 95, 97, 89, 78, 79, 89, 100, 67, 0, 63, 80, 64.\n\
Требуется найти: 1) дисперсию Var(Х); 2) центральный момент из μ3(Х).\n\
\n\
\n\
grades = [95, 12, 0, 3, 63, 64, 0, 63, 100, 96, 54, 79, 0, 98, 71, 68, 95, 97, 89, 78, 79, 89, 100, 67, 0, 63, 80, 64]\n\
k = 6\n\
\n\
grades = np.array(grades)\n\
n = len(grades)\n\
\n\
var = grades.var() / k\n\
print(var) #Дисперсия\n\
\n\
mu3 = np.sum((grades - grades.mean()) ** 3) / n / k ** 2\n\
print(mu3) # Центральный момент"
        ,
        "4.7":"В группе учатся Ω студенты: ω , . . . , 1 ω30. Пусть X и Y – 100-балльные экзаменационные оценки по\n\
математическому анализу и теории вероятностей. Оценки студента ωi обозначаются: xi = X(ωi)  и  yi = Y (ωi),\n\
i = 1, . . . , 30. Все оценки известны: x1 = 73, y1 = 69 x2 = 39, y2 = 43 x3 = 87, y3 = 88 x4 = 60, y4 = 41\n\
x5 = 79, y5 = 95 x6 = 86, y6 = 98 x7 = 47, y7 = 46 x8 = 42, y8 = 58 x9 = 44, y9 = 43 x10 = 66, y10 = 56\n\
x11 = 47, y11 = 47 x12 = 80, y12 = 85 x13 = 39, y13 = 35 x14 = 73, y14 = 65 x15 = 62, y15 = 77\n\
x16 = 44, y16 = 55 x17 = 44, y17 = 60 x18 = 56, y18 = 43 x19 = 39, y19 = 44 x20 = 86, y20 = 64\n\
x21 = 40, y21 = 39 x22 = 84, y22 = 82 x23 = 74, y23 = 56 x24 = 73, y24 = 68 x25 = 51, y25 = 34\n\
x26 = 38, y26 = 52 x27 = 65, y27 = 65 x28 = 57, y28 = 53 x29 = 33, y29 = 50 x30 = 72, y30 = 94\n\
Требуется найти следующие условные эмпирические характеристики: 1) ковариацию X и Y\n\
при условии, что одновременно X ⩾ 50 и Y ⩾ 50 коэффициент корреляции X и Y при том же условии\n\
\n\
\n\
xy='x1 = 73, y1 = 69 x2 = 39, y2 = 43 x3 = 87, y3 = 88 x4 = 60, y4 = 41 x5 = 79, y5 = 95 x6 = 86, y6 = 98 x7 = 47, y7 = 46\\n\
x8 = 42, y8 = 58 x9 = 44, y9 = 43 x10 = 66, y10 = 56 x11 = 47, y11 = 47 x12 = 80, y12 = 85 x13 = 39, y13 = 35\\n\
x14 = 73, y14 = 65 x15 = 62, y15 = 77 x16 = 44, y16 = 55 x17 = 44, y17 = 60 x18 = 56, y18 = 43 x19 = 39, y19 = 44\\n\
x20 = 86, y20 = 64 x21 = 40, y21 = 39 x22 = 84, y22 = 82 x23 = 74, y23 = 56 x24 = 73, y24 = 68 x25 = 51, y25 = 34\\n\
x26 = 38, y26 = 52 x27 = 65, y27 = 65 x28 = 57, y28 = 53 x29 = 33, y29 = 50 x30 = 72, y30 = 94'\n\
sample=np.array(list(map(lambda x: (int(x[0].split('=')[1]), int(x[1].split('=')[1])), list(map(lambda x: x.split(','), xy.split('x')))[1:])))\n\
x_all = sample[:, 0]\n\
y_all = sample[:, 1]\n\
\n\
x = []\n\
y = []\n\
\n\
for x_t, y_t in zip(x_all, y_all):\n\
if x_t >= 50 and y_t >= 50:\n\
    x.append(x_t)\n\
    y.append(y_t)\n\
\n\
x = np.array(x)\n\
y = np.array(y)\n\
\n\
cov = 0\n\
for x_t, y_t in zip(x, y):\n\
cov += (x_t - x.mean()) * (y_t - y.mean())\n\
cov /= len(x)\n\
print(cov) # ковариация\n\
\n\
print(cov/np.sqrt(x.var()*y.var())) # коэффицент корреляции"
        ,
        "4.8":"Поток Ω состоит k из групп: Ω , . . . , 1 Ωk, k = 5. На потоке учатся n = n1+. . . +nk студентов, где ni–\n\
число студентов в группе Ωi i = 1, . . . , k . Пусть X(ω)– 100-балльная оценка студента ω ∈ Ω. Далее\n\
используются следующие обозначения: X¯i– среднее значение, σi– (эмпирическое) стандартное отклонение\n\
признака X на группе Ωi . Дано: n1 = 22 n2 = 29 n3 = 28 n4 = 25 n5 = 20 x1 = 74 x2 = 73 x3 = 72 x4 = 79 x\n\
5 = 80 σ1 = 9 σ2 = 4 σ3 = 7 σ4 = 3 σ5 = 8. Требуется найти: 1) среднее значение на потоке\n\
; 2) (эмпирическое) стандартное отклонение на потоке .\n\
\n\
\n\
n1=22\n\
n2=29\n\
n3=28\n\
n4=25\n\
n5=20\n\
xm1=74\n\
xm2=73\n\
xm3=72\n\
xm4=79\n\
xm5=80\n\
si1=9\n\
si2=4\n\
si3=7\n\
si4=3\n\
si5=8\n\
\n\
M = (n1 * xm1 + n2 * xm2 + n3 * xm3 + n4 * xm4 + n5 * xm5)/(n1 + n2 + n3 + n4 + n5)\n\
print(M) #среднее значение \n\
\n\
var_all = (n1 * (xm1 - M)**2 + n2 * (xm2 - M)**2 + n3 * (xm3 - M)**2 + n4 * (xm4 - M)**2 + n5 * (xm5 - M)**2)/(n1 + n2 + n3 + n4 + n5)\n\
var_mean_all = (n1 * si1**2 + n2 * si2**2 + n3 * si3**2 + n4 * si4**2 + n5 * si5**2)/(n1 + n2 + n3 + n4 + n5)\n\
\n\
np.sqrt(var_all + var_mean_all) # стандартное октлонение"
        ,
        "5.1":"Пусть х = (x1, ..., х25) - реализация случайной выборки Х (Х1,..., Х25) из нормального распределения\n\
N(Hx; 0,82), а ў = (91, ..., У35) реализация случайной выборки Y = (Y1,..., Ү35) из нормального распределения\n\
N(Hy; 1,42). Известно, что Х и Ў независимы. Проверяется гипотеза Но : Hz Ну против альтернативной гипотезы Н1 : 4х > Ну.\n\
При уровне значимости а применяется критерий с критической областью {Z> A}, где статистика критерия Z = Z(X, Y) это нормированная\n\
разность Х — Ў, А = Aa Соответствующее критическое множество имеет вид Ка = (Aa; ∞). 1) Найдите значение статистики критерия 7 набл.\n\
Z(х,у). 2) Найдите Р-значение критерия. 3) Найдите критическое значение А, критическое множество Ка и проверьте гипотезу Но при а = 0,03.\n\
4) Найдите мощность критерия W в случае 4x — Hy = 0,6 иа = = 0,03. ИсÃоÄнÜе Äанные: π = (4,837; 2,78; 4,868; 5,183; 2,87; 1,781; 2,421; 2,683;\n\
2,7; 3,764; 2,697; 3,572; 5,147; 4,114; 5,962; 3,183; 3,25; 5,03; 3,894; 4,279; 3,05; 4,855; 4,243; 5,05; 4,536); y = (3,539; 5,746; 2,145; 3,284; 4,602;\n\
3,135; 3,417; 3,694; 0,047; 4,838; 2,735; 4,183; 4,738; 2,781; 4,129; 4,695; 4,016; 3,517; 4,747; 1,872; 5,439; 0,861; 2,821; 4,437; 4,006; 7,154; 4,244;\n\
4,083; 5,911; 2,052; 4,124; 3,738; 4,555; 1,084; 3,996).\n\
\n\
\n\
\n\
Z = norm()\n\
\n\
def Phi0(x):\n\
return Z.cdf(x) - 1 / 2\n\
\n\
def convert(s):\n\
s = s.replace(',', '.').replace(';', ',')\n\
data = map(float, s.split(','))\n\
return list(data)\n\
\n\
x = convert('4,837; 2,78; 4,868; 5,183; 2,87; 1,781; 2,421; 2,683; 2,7; 3,764; 2,697; 3,572; 5,147; 4,114; 5,962; 3,183; 3,25; 5,03; 3,894; 4,279; 3,05; 4,855; 4,243; 5,05; 4,536')\n\
x = np.array(x)\n\
n = len(x)\n\
\n\
y = convert('3,539; 5,746; 2,145; 3,284; 4,602; 3,135; 3,417; 3,694; 0,047; 4,838; 2,735; 4,183; 4,738; 2,781; 4,129; 4,695; 4,016; 3,517; 4,747; 1,872; 5,439; 0,861; 2,821; 4,437; 4,006; 7,154; 4,244; 4,083; 5,911; 2,052; 4,124;3,738; 4,555; 1,084; 3,996')\n\
y = np.array(y)\n\
m = len(y)\n\
\n\
sx = 0.8\n\
sy = 1.4\n\
alpha = 0.03\n\
delta = 0.6\n\
z = (x.mean() - y.mean()) / np.sqrt(sx ** 2 / n + sy ** 2 / m)\n\
print(z) # Значение статически критерия\n\
P = Z.sf(z)\n\
print(P)# P-значение кртиерия\n\
A = Z.isf(alpha)\n\
print(A)# Критическое занчение А\n\
beta = 1 / 2 + Phi0(A - np.sqrt(m * n) / np.sqrt(m * sx ** 2 + n * sy ** 2) * delta)\n\
W = 1 - beta\n\
print(W)# Мощность кртиерия"
        ,
        "5.2":"Пусть x = (x1,…, x20) реализация случайной выборки Х = (Х1,..., Х20) из нормального распределения\n\
N(μ; σ2 ). Проверяется на уровне значимости а = 0,04 основная гипотеза Но: м = 1,45 против альтернативной гипотезы\n\
Н₁: µ ≠ 1,45 с критическим множеством вида Ка =(-∞,-A) U (A,+00).\n\
1)Найдите значение статистики критерия t = T = T( ) набл. x⃗. 2) Найдите границу А критического множества.\n\
3) Найдите Р-значение критерия и сделайте выводы. 4)\n\
Найдите мощность W критерия для H1: μ = 1,34. Исходные данные:\n\
2 = (1,494; 0,274; 10,106; 1,165; 1,411; -0,809; 0,617; 4,121; 6,242; -3,752; 0,98; 0,884; 6,619;\n\
1,781; 6,055; -3,969; 1,481; 4,778; -4,171; 1,672).\n\
\n\
\n\
Z = norm()\n\
\n\
def Phi0(x):\n\
return Z.cdf(x) - 1 / 2\n\
\n\
def convert(s):\n\
s = s.replace(',', '.').replace(';', ',')\n\
data = map(float, s.split(','))\n\
return list(data)\n\
\n\
x = convert('1,494; 0,274; 10,106; 1,165; 1,411; -0,809; 0,617; 4,121; 6,242; -3,752; 0,98; 0,884; 6,619; 1,781; 6,055; -3,969; 1,481; 4,778; -4,171; 1,672')\n\
x = np.array(x)\n\
n = len(x)\n\
\n\
alpha = 0.04\n\
mu0 = 1.45\n\
mu1 = 1.34\n\
T = np.sqrt(n - 1) * (x.mean() - mu0) / x.std(ddof=0)\n\
print(T) #значение стат критерия\n\
A = t(n - 1).isf(alpha / 2)\n\
print(A)# граница А крит множества\n\
P = 2 * min(t(n - 1).cdf(T), t(n - 1).sf(T))\n\
print(P)#P-знгачение кртиерия\n\
delta = np.sqrt(n - 1) * (mu1 - mu0) / x.std()\n\
t2 = t(n - 1).isf(alpha / 2)\n\
beta = nct(n - 1, delta).cdf(t2) - nct(n - 1, delta).cdf(-t2)\n\
W = 1 - beta\n\
print(W)# мощность критерия"
        ,
        "5.3":"Для трех групп финансовых показателей А, В, С проверяется гипотеза о совпадении ожидаемых значений показателей.\n\
Предполагается, что все показатели Хіj независимы и распределены по нормальному закону N(μj, σ )2 с одинаковой неизвестной\n\
дисперсией Var(X₁₁) = 0², причем для каждой группы (E(Xij ) = μj, j = 1, 2, 3. 1) По данным значениям (файл ds5.9.8.csv) найдите\n\
межгрупповую и среднюю групповую дисперсии. 2) Найдите 91% доверительные интервалы для ожидаемых значений показателей μj, j = 1, 2, 3.\n\
3) Найдите значение статистики критерия f0 = Fнабл., критическое множество Ка и на 3% уровне значимости проверьте гипотезу о совпадении\n\
ожидаемых значений показателей, μ1 = μ2 = μ3. 4) Найдите Р-значение критерия и сделайте выводы\n\
\n\
\n\
data=pd.read_csv('ds5.9.8.csv', header=None, decimal=',', sep=';',encoding='cp1251')\n\
A, B, C = data[0], data[1], data[2]\n\
A = A.dropna()\n\
B = B.dropna()\n\
C = C.dropna()\n\
\n\
na = len(A)\n\
nb = len(B)\n\
nc = len(C)\n\
n = [na, nb, nc]\n\
N = sum(n)\n\
k = 3\n\
alpha = 0.03\n\
alpha2 = 1 - 0.91\n\
\n\
muabc = data.mean()\n\
varabc = data.var(ddof=0)\n\
mu0 = np.concatenate([A, B, C]).mean()\n\
\n\
d2 = np.sum((muabc - mu0) ** 2 * n) / N\n\
print(d2)# межгрупповая \n\
\n\
meanvar = np.sum(varabc * n) / N\n\
print(meanvar)#\n\
\n\
SSE = N * meanvar\n\
MSE = SSE / (N - k)\n\
SSTR = N * d2\n\
MSTR = SSTR / (k - 1)\n\
F = MSTR / MSE\n\
print(F)#\n\
\n\
print(f'({f(k - 1, N - k).isf(alpha)}, ∞)')#\n\
\n\
pv = f(k - 1, N - k).sf(F)\n\
print(pv)#\n\
\n\
left = muabc - t(N - k).isf((alpha2) / 2) * np.sqrt(MSE / n)\n\
right = muabc + t(N - k).isf((alpha2) / 2) * np.sqrt(MSE / n)\n\
\n\
for l, r, i in zip(left, right, [1,2,3]):\n\
print(f'mu{i} ∈ ({l}; {r}) ')#"
        ,
        "5.4":"Для трех групп финансовых показателей A: (X1; . . . ; X35), B:(Y1; . . . ; Y29) , C:(Z1; . . . ;Z31) , которые по предположению независимы\n\
и распределены, соответственно, по трем нормальным законам N(μx, σ2 ) N(μy, σ2 ) N(μz, σ2 ) (с одинаковой неизвестной дисперсией )\n\
на уровне значимости α = 0,01 с помощью F-критерия (Фишера) проверяется гипотеза H0: μx = μy = μz о совпадении ожидаемых\n\
значений показателей. Конкретные значения всех показателей указаны ниже. 1) По данным значениям показателей найдите межгрупповую\n\
дисперсию. 2) По этим же данным найдите среднюю групповую дисперсию. 3) Найдите значение статистики F-критерия, критическое\n\
множество Kα и проверьте гипотезу H0. 4) Найдите P-значение критерия и сделайте выводы.\n\
Значения показателей группы A: (-2,63; 2,812; 3,354; -1,754; 3,732; 0,411; 4,594; 8,272; 0,437; 10,205; 5,254; -0,846; 0,729; 3,799; 1,174; 2,885;\n\
1,489; -3,153; 2,788; 1,361; -0,556; 3,637; 0,484; -3,043; 0,471; 1,513; 4,164; 2,327; 3,715; 1,989; 3,666; 5,35; 4,509; 7,537; 0,258). Значения\n\
показателей группы B: (0,024; -1,306; 2,986; 2,237; 3,289; 5,557; 1,174; 2,651; 3,268; 2,492; 2,516; 0,924; 5,502; 4,909; -0,901; -0,13; 0,28; -1,594;\n\
1,728; 1,737; 1,491; 1,43; -1,218; 2,952; -0,516; 2,881; 1,591; 2,129; 0,819). Значения показателей группы C: (-0,638; 2,623; 6,466; -1,684; 4,656;\n\
-0,655; 2,152; 1,103; 0,503; 4,185; 0,627; -0,555; -0,98; 0,852; -1,945; 5,233; 3,124; -4,2; 0,958; 4,156; 0,936; -1,321; 0,573; 0,164; 1,11; 5,099;\n\
0,084; 0,934; 0,941; -1,156; -2,437).\n\
\n\
\n\
\n\
Z = norm()\n\
\n\
def Phi0(x):\n\
return Z.cdf(x) - 1 / 2\n\
\n\
def convert(s):\n\
s = s.replace(',', '.').replace(';', ',')\n\
data = map(float, s.split(','))\n\
return list(data)\n\
\n\
x = convert('-2,63; 2,812; 3,354; -1,754; 3,732; 0,411; 4,594; 8,272; 0,437; 10,205; 5,254; -0,846; 0,729; 3,799; 1,174;2,885; 1,489; -3,153; 2,788; 1,361; -0,556; 3,637; 0,484; -3,043; 0,471; 1,513; 4,164; 2,327; 3,715; 1,989; 3,666; 5,35; 4,509; 7,537; 0,258')\n\
x = np.array(x)\n\
n1 = len(x)\n\
\n\
y = convert('0,024; -1,306; 2,986; 2,237; 3,289; 5,557; 1,174; 2,651; 3,268; 2,492; 2,516; 0,924; 5,502; 4,909; -0,901; -0,13; 0,28; -1,594; 1,728; 1,737; 1,491; 1,43; -1,218; 2,952; -0,516; 2,881; 1,591; 2,129; 0,819')\n\
y = np.array(y)\n\
n2 = len(y)\n\
\n\
z = convert('-0,638;2,623; 6,466; -1,684; 4,656; -0,655; 2,152; 1,103; 0,503; 4,185; 0,627; -0,555; -0,98; 0,852; -1,945; 5,233; 3,124; -4,2; 0,958; 4,156; 0,936;-1,321; 0,573; 0,164; 1,11; 5,099; 0,084; 0,934; 0,941; -1,156; -2,437')\n\
z = np.array(z)\n\
n3 = len(z)\n\
\n\
xyz = pd.DataFrame([x, y, z]).T\n\
xyz_all = np.concatenate([x, y, z])\n\
n = [n1, n2, n3]\n\
N = sum(n)\n\
k = 3\n\
alpha = 0.01\n\
\n\
d2 = np.sum((xyz.mean() - xyz_all.mean()) ** 2 * n) / N\n\
print(d2)#межгрупповая дисперсия\n\
\n\
meanvar = np.sum(xyz.var(ddof=0) * n) / N\n\
print(meanvar)#ср. групповая дисперсия\n\
\n\
SSE = N * meanvar\n\
MSE = SSE / (N - k)\n\
SSTR = N * d2\n\
MSTR = SSTR / (k - 1)\n\
F = MSTR / MSE\n\
print(F)#знач. стст. кртиерия\n\
f(k - 1, N - k).isf(alpha) #для проверки гипотезы\n\
P = f(k - 1, N - k).sf(F)\n\
print(P)# Р-значение кртиерия"
        ,
        "5.5":"Пусть x⃗ = (x1,…, x20)– реализация случайной выборки X⃗ = ( X1,…,X20 ) из нормального распределения N(μ; 3,6^2 )\n\
Проверяется на уровне значимости α = 0,01 основная гипотеза H0 : μ = 1,91 против альтернативной гипотезы H1 : μ ≠ 1,91 с\n\
критическим множеством вида Kα = (−∞, −A) ∪ (A, +∞)  . 1) Найдите значение статистики критерия Zнабл = Z( x⃗). 2) Найдите\n\
границу А критического множества. 3) Найдите P-значение критерия и сделайте выводы. 4) Найдите мощность W критерия для H1 : μ = 1,78.\n\
Исходные данные:x⃗= (1,943; -1,37; 0,323; 3,293; 1,332; 3,173; 2,409; 4,521; 5,488; 2,914; 4,19; 4,483; 3,192; 7,648; 0,835; 2,648; 2,264;\n\
-5,505; -0,958; 5,399).\n\
\n\
\n\
\n\
Z = norm()\n\
\n\
def Phi0(x):\n\
return Z.cdf(x) - 1 / 2\n\
\n\
def convert(s):\n\
s = s.replace(',', '.').replace(';', ',')\n\
data = map(float, s.split(','))\n\
return list(data)\n\
\n\
x = convert('1,943; -1,37; 0,323; 3,293; 1,332; 3,173; 2,409; 4,521; 5,488; 2,914; 4,19; 4,483; 3,192; 7,648; 0,835; 2,648; 2,264;-5,505; -0,958; 5,399')\n\
x = np.array(x)\n\
n = len(x)\n\
\n\
s = 3.6\n\
alpha = 0.01\n\
mu0 = 1.91\n\
mu1 = 1.78\n\
\n\
z = np.sqrt(n) * (x.mean() - mu0) / s\n\
print(z)#знач. стат. критерия\n\
A = Z.isf(alpha / 2)\n\
print(A)# граница А крит. множества\n\
P = 2 * min(Z.cdf(z), Z.sf(z))\n\
print(P)# Р-значение\n\
beta = Phi0(A - np.sqrt(n) * (mu1 - mu0) / s) + Phi0(A + np.sqrt(n) * (mu1 - mu0) / s)\n\
W = 1 - beta\n\
print(W)#Мощность критерия"
        ,
        "6.1":"По содержащейся в файле ds6.4.12.csv реализации случайной выборки из двумерного нормального\n\
распределенияN ((E(X); E(Y )); || Var(X)   Cov(X,Y)||)= N ((2; 2); ||σ^2  ρσ^2||)\n\
                            || Cov(X,Y) Var(Y)  ||)             ||ρσ^2 σ^2 ||)\n\
с неизвестными параметрами ρ ∈ (−1; 1) и σ > 0 \n\
и : 1) запишите логарифм функции правдоподобия,lnL(ρ, σ) ; 2) найдите оценки максимального\n\
правдободобия ρˆ и σˆ.\n\
\n\
\n\
from sympy import *\n\
data = pd.read_csv('ds6.4.12.csv', header=None, decimal=',', sep=';',encoding='cp1251')\n\
X = np.array(data[0])\n\
Y = np.array(data[1])\n\
mux, muy = 2, 2\n\
n=len(data)\n\
sigma, rho, pi = symbols('sigma, rho, pi')\n\
A = 1/n * sum((X-mux)**2)\n\
B = 1/n * sum((Y-muy)**2)\n\
C = 1/n * sum((X-mux)*(Y-muy))\n\
\n\
term = (A + B - 2*C*rho)/(2*(1-rho**2)*sigma**2)\n\
lnL_exp = -log(2*pi) - 1/2*log(1-rho**2) - log(sigma**2) - term\n\
lnL = -np.log(2*np.pi) - 1/2*log(1-rho**2) - log(sigma**2) - term\n\
\n\
dif_sigma = diff(lnL, sigma)\n\
dif_rho = diff(lnL, rho)\n\
sol = solve([dif_sigma, dif_rho], [rho, sigma])\n\
print(sol) #оценки ρˆ, σˆ\n\
lnL_exp #уравнение"
        ,
        "6.2":"Пусть (x1, y1); . . . ;(x36, y36)– реализация случайной выборки (X1, Y1); . . . ;(X36, Y36) из двумерного\n\
нормального распределения N(μx; μy; (σ^2)x ;(σ^2)y  ; ρ). Используя векторы x⃗ = (x1; . . . ; x36) и y⃗ = (y1; . . . ; y36) , постройте\n\
асимптотический 0,73-доверительный интервал (θˆ1, θˆ2)\n\
для коэффициента корреляции ρ. В ответе укажите: 1)\n\
выборочный коэффициент корреляции ρˆ 2) верхнюю границу θˆ2 построенного доверительного интервала для ρ.\n\
Исходные данные: x⃗= (-1,377; -0,664; 0,544; -0,259; -0,162; -0,065; -1,324; 0,561; 0,382; 1,482; -1,113; -0,68; 0,536; -0,541;\n\
-1,348; -0,287; 0,964; 1,353; -0,095; -0,008; -0,505; 2,807; 1,258; -0,517; 2,763; 0,285; -0,836; 0,891; 0,785; 0,811; 0,08; -0,09;\n\
1,637; 2,165; 0,911; -2,165), y⃗= (-1,466; -0,554; 0,575; 0,284; -0,779; 0,179; -1,809; 0,707; 0,108; 1,174; -1,672; -0,654;\n\
-0,187; -0,643; -0,995; 0,489; 0,69; 1,612; 0,176; 0,275; -0,217; 2,311; 1,107; -0,395; 2,467; 0,362; -0,978; 0,975; 0,439; 0,765;\n\
0,154; -0,308; 1,404; 1,674; 0,816; -1,418).\n\
\n\
\n\
def convert(s):\n\
s = s.replace(',', '.').replace(';', ',')\n\
data = map(float, s.split(','))\n\
return list(data)\n\
\n\
x = convert('-1,377; -0,664; 0,544; -0,259; -0,162; -0,065; -1,324; 0,561; 0,382; 1,482; -1,113; -0,68; 0,536; -0,541; -1,348; -0,287;0,964; 1,353; -0,095; -0,008; -0,505; 2,807; 1,258; -0,517; 2,763; 0,285; -0,836; 0,891; 0,785; 0,811; 0,08; -0,09; 1,637; 2,165; 0,911; -2,165')\n\
y = convert('-1,466; -0,554; 0,575; 0,284; -0,779; 0,179; -1,809; 0,707; 0,108; 1,174; -1,672; -0,654; -0,187; -0,643; -0,995; 0,489; 0,69; 1,612; 0,176;0,275; -0,217; 2,311; 1,107; -0,395; 2,467; 0,362; -0,978; 0,975; 0,439; 0,765; 0,154; -0,308; 1,404; 1,674; 0,816; -1,418')\n\
x = np.array(x)\n\
y = np.array(y)\n\
gamma = 0.73\n\
n = len(x)\n\
\n\
Z = norm(0, 1)\n\
\n\
ro_hat = np.cov(x, y, ddof=0)[0, 1] / x.std() / y.std()\n\
print(ro_hat)\n\
\n\
u_left = np.arctanh(ro_hat) - 1 / np.sqrt(n - 3) * Z.isf((1 - gamma) / 2)\n\
u_right = np.arctanh(ro_hat) + 1 / np.sqrt(n - 3) * Z.isf((1 - gamma) / 2)\n\
\n\
np.tanh(u_left), np.tanh(u_right)# выборочный коэф.корр; верхняя граница довер. интервала "
        ,
        "6.3":"Фёдор и Ева исследуют эффективность лекарственного препарата АВС. Фёдор, используя модель Евы, создал компьютерную\n\
программу, вычисляющую по заданным генетическим факторам вероятность (в процентах) успешного применения АВС. Программа\n\
Фёдора накапливает полученные вероятности и в итоге выдает набор частот:n0, n1, . . . , n100 . Например, n75– это число случаев, в\n\
которых программа Фёдора получила вероятность 75%. Обработав 500 образцов генетического материала, Ева нашла значения\n\
факторов и ввела их в программу. В результате был получен следующий набор частот: 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1, 2, 0, 1, 1, 0, 1, 1,\n\
1, 1, 0, 4, 6, 3, 3, 1, 3, 5, 6, 4, 5, 6, 7, 5, 6, 6, 9, 11, 10, 7, 11, 13, 10, 13, 8, 10, 9, 20, 10, 11, 15, 9, 10, 10, 13, 18, 18, 13, 12, 10, 14, 11, 12,\n\
11, 9, 8, 10, 10, 6, 6, 4, 5, 8, 3, 4, 1, 4, 3, 1, 2, 3, 1, 0, 3, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0. Для завершения этапа исследования\n\
необходимо было подобрать распределение, соответствующее полученным частотам. Ева решила использовать распределение на\n\
отрезке [0, 1] с плотностью f(x) = f(x; a, b) = abx^(a−1)(1 − x^a)^b−1и целочисленными параметрами a, b в диапазоне от 1 до 20. В\n\
результате максимизации функции правдоподобия (при указанных ограничениях) Фёдором были получены значения параметров:\n\
a^ = A и b^ = B. Задача: пусть X– случайная величина, распределения на отрезке [0, 1] с плотностью f(x) = f(x; a^, b^) ,F(x)– ее\n\
функция распределения. Требуется найти математическое ожидание E(X) и X0,2 = F (0,2) – квантиль уровня 0,2. Какой смысл\n\
для всей популяции имеют E(X) и X0,2 ? В ответе укажите: 1) значение А ; 2) значение В ; 3) математическое ожидание E(X); 4)\n\
квантиль X0,2 .\n\
\n\
\n\
q = [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 1, 2, 1, 1, 0, 2, 1, 3, 5, 5, 3, 6, 3, 5, 8, 7, 6, 4, 7, 17, 15, 15, 13, 13, 12, 21, 24, 17, 26, 21, 27, 34, 29, 19, 22, 22, 22, 16, 13, 9, 11, 5, 2, 3, 0, 0, 0, 0, 0]\n\
quantil = 0.2\n\
\n\
sample = []\n\
for i in range(len(q)):\n\
temp = [i] * q[i]\n\
sample.extend(temp)\n\
sample = np.array(sample) / 100\n\
\n\
def f(x, a, b):\n\
return a * b * x ** (a - 1) * (1 - x ** a) ** (b - 1)\n\
def lnL(p, data):\n\
n = len(data)\n\
a, b = p\n\
return n * np.log(a * b) + (a - 1) * np.sum(np.log(data)) + (b - 1) * np.sum(np.log(1 - data ** a))\n\
\n\
\n\
\n\
res = minimize(fun=lambda p, data: -lnL(p, data), x0=np.array([0.1, 0.1]), args=(sample,), method='BFGS')\n\
a_hat, b_hat = res.x\n\
print(a_hat, b_hat)\n\
\n\
print(integrate.quad(lambda x: x * f(x, round(a_hat), round(b_hat)), 0, 1)[0])\n\
\n\
print((1-(1-quantil)**(1/round(b_hat)))**(1/round(a_hat)))"
        ,
        "test2":"группе учится 29 студентов. Ими были получены следующие 100-балльные оценки:\n\
90, 79, 53, 62, 66, 68, 75, 0, 82, 29, 0, 29, 68, 90, 0, 60, 44, 44, 70, 68, 70, 89, 0, 68, 0, 66, 0, 59, 70. Найдите:\n\
1) А - среднюю положительную оценку в группе, 2) М медиану положительных оценок в группе;\n\
3) Н - среднее гармоническое и G - среднее геометрическое оценок, которые не менее М;\n\
4) Q- медианную оценку в той ча группы, в которой студенты набрали не менее М. баллов;\n\
5) количество студентов, оценки которых оказались между Ни Q (включая границы).\n\
\n\
\n\
marks = np.array([90, 79, 53, 62, 66, 68, 75, 0, 82, 29, 0, 29, 68, 90, 0, 60, 44, 44, 70, 68, 70, 89, 0, 68, 0, 66, 0, 59, 70])\n\
\n\
print(marks[marks>0].mean())\n\
\n\
M = np.median(marks[marks!=0])\n\
print(M)\n\
\n\
H = scs.hmean(marks[marks>=M])\n\
print(H)\n\
\n\
G = scs.gmean(marks[marks>=M])\n\
print(G)\n\
\n\
Q = np.median(marks[marks>=M])\n\
print(Q)\n\
\n\
print(len(marks[(marks >= min(H,Q)) & (marks <= max(H,Q))]))\n\
\n\
\n\
#-----------------------------------------------------------------------------------------------------------------------------\n\
\n\
Следующие 28 чисел это умноженные на 10000 и округленные до ближайшего целого дневные логарифмические доходности акции компании АВС:\n\
-9, 9, 138, 145, 186, 78, 34, 37, -19, 68, 82, 158, 96, 189, 24, 84, 99, 125, -39, 26, 62, 91, 239, 211, 2, 129, 2, 16.\n\
Будем называть их преобразованными доходностями (ПД). Финансовый аналитик Глеб предполагает, что преобразованные доходности (\n\
как и исходные) приближенно распределены по нормальному закону. Чтобы проверить свое предположение Глеб нашел нижнюю квартиль\n\
1 и верхнюю квартиль Н нормального распределения (р.а²), для которого и это среднее арифметическое ПД, а эмпирическое стандартное\n\
отклонение ПД. Затем Глеб подсчитал количество ПД, попавших в интервал от 1 до Н (надеясь, что в этот интервал попадет половина ПД).\n\
Результат этого вычисления показался ему недостаточно убедительным. Чтобы окончательно развеять сомнения относительно нормальности ПД,\n\
Глеб построил на одном рисунке графики функций F(z) и F(z), где (г)- эмпирическая функция распределения ПД, а F() функция распределения\n\
(4, 2). В качестве меры совпадения двух графиков Глеб решил использовать расстояние в между функциями F(z) и F(z), которое он вычислил,\n\
исходя из определения: sup|F(z) F(z). В ответе укажите результаты вычислений Глеба: 1) среднее арифметическое ПД.\n\
2) эмпирическое стандартное отклонение ПД; 3) квартили и н;\n\
4) количество ПД, попавших в интервал от 1 до Н; 5) расстояние между функциями F(x) и F(x)\n\
\n\
\n\
vals = np.array([-9, 9, -138, -145, 186, 78, 34, -37, -19, -68, -82, 158, 96, -189, 24, 84, -99, 125, -39, 26, 62, -91, 239, \\n\
            -211, 2, 129, 2, -16])\n\
\n\
v_mean = vals.mean()\n\
v_std = vals.std()\n\
print(v_mean, v_std)#ср. арифм. ПД; эпирическое стандарт. отклонение ПД\n\
\n\
X = scs.norm(v_mean, v_std)\n\
L = X.ppf(0.25)\n\
H = X.ppf(0.75)\n\
print(L, H)#L,H\n\
\n\
print(len(vals[(vals >= L) & (vals <= H)]))#колличество ПД\n\
\n\
xsort=sorted(vals)\n\
n=len(xsort)\n\
\n\
res_d = float('-inf')\n\
for i in range(len(xsort)):\n\
maxx=max(abs((i+1)/n-X.cdf(xsort[i])),abs((i)/n-X.cdf(xsort[i])))\n\
if maxx > res_d:\n\
    res_d = maxx\n\
    d_ind = i\n\
print(res_d, d_ind)#расстояние между функциями распределений\n\
\n\
\n\
#-----------------------------------------------------------------------------------------------------------------------------\n\
\n\
\n\
В группе Я учатся студенты: 1,..., 30. Пусть Х и У 100-балльные экзаменационные оценки по математическому анализу и теории вероятностей.\n\
Оценки студента шу обозначаются: х = Х(ш) и у = Y(). i 1,..., 30. Все оценки известны: 2171,3171,2252, 258, 2372, y381,2487,492,581,9581,\n\
26100,3694,2790,9796, 2854,3846, 2954, 3/960, 21058, 3/1062, 21156, 9/11 149, 1270, 391260, 21393, 3/1386, 21446, 91448, 21556,91561, 21659,\n\
31652, 1742, 91740, 21860, 3/1860, 1933, 2/1937, 2083, 920 92, 22150,92157, 222 93, 92293, 223 41,923 42, 202455, 192464, 22560, 1/2559, 237,\n\
2030, 22771,92771, 22842, 92844,285,92982, 230 = 39, узо = 39. Требуется найти следующие условные эмпирические характеристики:\n\
1) ковариацию Х и У при условии, что одновременно Х≥ 50 и У≥ 50; 2) коэффициент корреляции Х и У при том же условии\n\
\n\
\n\
import re\n\
\n\
s = '''x1=71,y1=71\n\
, x2=52,y2=58\n\
, x3=72,y3=81\n\
, x4=87,y4=92\n\
, x5=81,y5=81\n\
, x6=100,y6=94\n\
, x7=90,y7=96\n\
, x8=54,y8=46\n\
, x9=54,y9=60\n\
, x10=58,y10=62\n\
, x11=56,y11=49\n\
, x12=70,y12=60\n\
, x13=93,y13=86\n\
, x14=46,y14=48\n\
, x15=56,y15=61\n\
, x16=59,y16=52\n\
, x17=42,y17=40\n\
, x18=60,y18=60\n\
, x19=33,y19=37\n\
, x20=83,y20=92\n\
, x21=50,y21=57\n\
, x22=93,y22=93\n\
, x23=41,y23=42\n\
, x24=55,y24=64\n\
, x25=60,y25=59\n\
, x26=37,y26=30\n\
, x27=71,y27=71\n\
, x28=42,y28=44\n\
, x29=85,y29=82\n\
, x30=39,y30=39\n\
'''\n\
match = re.findall(r'=(\d+)', s)\n\
x_all = list(map(int, match[::2]))\n\
y_all = list(map(int, match[1::2]))\n\
\n\
x = []\n\
y = []\n\
\n\
for x_t, y_t in zip(x_all, y_all):\n\
if x_t >= 50 and y_t >= 50:\n\
    x.append(x_t)\n\
    y.append(y_t)\n\
\n\
x = np.array(x)\n\
y = np.array(y)\n\
\n\
cov = 0\n\
for x_t, y_t in zip(x, y):\n\
cov += (x_t - x.mean()) * (y_t - y.mean())\n\
cov /= len(x)\n\
print(cov)\n\
print(cov/np.sqrt(x.var()*y.var()))\n\
\n\
#-----------------------------------------------------------------------------------------------------------------------------\n\
\n\
\n\
Поток Ω состоит из k групп. Ω1,...,Ωk=3. На потоке учатся в n=n1+... +nk студентов, где ni - число студентов в группе Ωi, i=1,...,k. Пусть Х(w) 100-балльная оценка студента X є Ω. Далее\n\
используются следующие обозначения: xi, среднее значение, т. (эмпирическое) стандартное отклонение признака Х на группе Ωi. Дано: п₁ = 24, па = 26, 330, 2= 70 = 76.2 = 77.0=400 8.\n\
Требуется найти: 1) среднее значение Х на потоке Ω. 2) (эмпирическое) стандартное отклонение Х на потоке Ω\n\
\n\
\n\
n1=24\n\
n2=26\n\
n3=30\n\
xm1=70\n\
xm2=76\n\
xm3=77\n\
si1=4\n\
si2=6\n\
si3=8\n\
M = (n1 * xm1 + n2 * xm2 + n3 * xm3)/(n1 + n2 + n3)\n\
print(M)# ср. знач\n\
var_all = (n1 * (xm1 - M)**2 + n2 * (xm2 - M)**2 + n3 * (xm3 - M)**2)/(n1 + n2 + n3)\n\
var_mean_all = (n1 * si1**2 + n2 * si2**2 + n3 * si3**2)/(n1 + n2 + n3)\n\
print(np.sqrt(var_all + var_mean_all))# стандарт отклонение"
        ,
        "test3":"Пусть (x1,y1);...;(x31,y31)– реализация случайной выборки (X1,Y1);...;(X31,Y31)\n\
из двумерного нормального распределения N(μx;μy;σ2x;σ2y;ρ).\n\
Используя векторы x⃗ =(x1;...;x31) и y⃗ =(y1;...;y31), постройте асимптотический 0,93-\n\
доверительный интервал (θˆ1;θˆ2) для коэффициента корреляции ρ. В ответе укажите: 1) выборочный коэффициент корреляции ρˆ;\n\
2) верхнюю границу θˆ2 построенного доверительного интервала для ρ.Исходные данные: x⃗ \n\
= (-0,616; -0,238; 0,173; -0,255; 0,531; 0,718; -0,161; 0,371; -1,014; -0,413; -1,571; 0,485; 0,486; 0,688; -0,944; 0,155; 0,003; 0,111; 0,752; 0,783; -0,102; -0,74; -2,097; 1,349; -0,044; -0,617; -0,782; -0,873; -0,995; -1,256; -0,596),\n\
y⃗ = (-1,34; -0,25; 0,101; -0,626; -0,088; 0,539; -0,451; 0,233; -1,186; -0,423; -1,329; 0,231; 0,209; 0,638; -0,274; -0,491; -0,319; 0,294; 0,895; 1,164; -0,57; -1,078; -1,526; 1,491; 0,182; -0,31; -1,001; -0,969; -0,918; -0,904; -0,595).\n\
\n\
\n\
\n\
\n\
x = np.array([-0.616, -0.238, 0.173, -0.255, 0.531, 0.718, -0.161, 0.371, -1.014, -0.413, -1.571, 0.485,\n\
            0.486, 0.688, -0.944, 0.155, 0.003, 0.111, 0.752, 0.783, -0.102, -0.74, -2.097, 1.349, -0.044,\n\
            -0.617, -0.782, -0.873, -0.995, -1.256, -0.596])\n\
y = np.array([-1.34, -0.25, 0.101, -0.626, -0.088, 0.539, -0.451, 0.233, -1.186, -0.423, -1.329, 0.231,\n\
            0.209, 0.638, -0.274, -0.491, -0.319, 0.294, 0.895, 1.164, -0.57, -1.078, -1.526, 1.491, 0.182,\n\
            -0.31, -1.001, -0.969, -0.918, -0.904, -0.595])\n\
gamma = 0.93\n\
\n\
# x = np.array([-1.598, 1.067, 0.789, 0.546, -2.166, -2.004, 0.489, 0.113, -0.902, -0.776, -0.164, -0.541, 0.71,\n\
#               0.082, -0.737, 0.655, 0.656, 0.498, -0.527, -0.185, 1.383, -0.283, -2.518, 0.688, 1.379, -0.254,\n\
#               0.886, 0.221, -0.905, 1.209, 0.128, -0.949, 1.046, 1.272, -1.226, -0.964, -0.72])\n\
# y = np.array([-2.102, 1.429, 1.516, 0.266, -1.612, -1.665, 1.203, 0.413, -0.96, -0.431, -0.575, -0.045, 0.654,\n\
#               0.773, -0.584, 0.857, 0.668, 0.751, -0.605, -0.594, 1.547, -0.045, -2.164, 1.106, 1.206, 0.388,\n\
#               0.577, -0.027, -1.309, 1.045, 0.85, -0.916, 1.362, 0.694, -1.108, -0.845, -0.963])\n\
# gamma = 0.77\n\
\n\
n = len(x)\n\
\n\
Z = norm(0, 1)\n\
\n\
ro_hat = np.cov(x, y, ddof=0)[0, 1] / x.std() / y.std()\n\
ro_hat\n\
\n\
u_left = np.arctanh(ro_hat) - 1 / np.sqrt(n - 3) * Z.isf((1 - gamma) / 2)\n\
u_right = np.arctanh(ro_hat) + 1 / np.sqrt(n - 3) * Z.isf((1 - gamma) / 2)\n\
\n\
print(np.tanh(u_left), np.tanh(u_right))# выборочный коэф. корреляции\n\
ro_hat# верхняя граница довер. интетрвала \n\
\n\
\n\
#-----------------------------------------------------------------------------------------------------------------------------\n\
\n\
\n\
Глеб и Анна исследуют эффективность лекарственного препарата АВС. Глеб, используя модель Анны, создал компьютерную программу, вычисляющую по заданным генетическим факторам\n\
вероятность (в процентах) успешного применения АВС. Программа Глеба накапливает полученные вероятности и в итоге выдает набор частот: n0,n1,...,n100. Например, n75\n\
– это число случаев, в которых программа Глеба получила вероятность 75%. Обработав 1000 образцов генетического материала, Анна нашла значения факторов и ввела их в программу.\n\
В результате был получен следующий набор частот: 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,\n\
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, 0, 1, 1, 3, 4, 4, 5, 4, 6, 6, 11, 9, 19, 23, 25, 33, 36, 36, 46, 46, 49, 58, 90, 76, 66, 69, 75, 68, 44,\n\
39, 21, 16, 5, 2, 1, 0, 0, 0. Для завершения этапа исследования необходимо было подобрать распределение, соответствующее полученным частотам. Анна решила использовать распределение на отрезке [0,1]\n\
с плотностью f(x)=f(x;a,b)=abxa−1(1−xa)b−1 и целочисленными параметрами a,b\n\
в диапазоне от 1 до 20. В результате максимизации функции правдоподобия (при указанных ограничениях) Глебом были получены значения параметров: a^=Aи b^=B\n\
. Задача: пусть X – случайная величина, распределения на отрезке [0,1] с плотностью f(x)=f(x;a^,b^), F(x)\n\
– ее функция распределения. Требуется найти математическое ожидание E(X) и X0, 2=F−1(0,2)\n\
– квантиль уровня 0,2. Какой смысл для всей популяции имеют E(X)и X0, 2\n\
? В ответе укажите: 1) значение A; 2) значение B; 3) математическое ожидание E(X); 4) квантиль X0, 2.\n\
\n\
\n\
q = [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,\n\
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, 0,\n\
    1, 1, 3, 4, 4, 5, 4, 6, 6, 11, 9, 19, 23, 25, 33, 36, 36, 46, 46, 49, 58, 90, 76, 66, 69, 75, 68,\n\
    44, 39, 21, 16, 5, 2, 1, 0, 0, 0]\n\
quantil = 0.2\n\
\n\
# q = [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,\n\
#      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 1, 2, 1, 1, 0, 2, 1, 3, 5, 5, 3, 6, 3, 5,\n\
#      8, 7, 6, 4, 7, 17, 15, 15, 13, 13, 12, 21, 24, 17, 26, 21, 27, 34, 29, 19, 22, 22, 22, 16, 13, 9, 11,\n\
#      5, 2, 3, 0, 0, 0, 0, 0]\n\
# quantil = 0.2\n\
\n\
sample = []\n\
for i in range(len(q)):\n\
temp = [i] * q[i]\n\
sample.extend(temp)\n\
sample = np.array(sample) / 100\n\
\n\
def f(x, a, b):\n\
return a * b * x ** (a - 1) * (1 - x ** a) ** (b - 1)\n\
\n\
#---------------------------------------------------------------\n\
\n\
def lnL(p, data):\n\
n = len(data)\n\
a, b = p\n\
return n * np.log(a * b) + (a - 1) * np.sum(np.log(data)) + (b - 1) * np.sum(np.log(1 - data ** a))\n\
\n\
#---------------------------------------------------------------\n\
\n\
from scipy.optimize import minimize\n\
\n\
res = minimize(fun=lambda p, data: -lnL(p, data), x0=np.array([0.1, 0.1]), args=(sample,), method='BFGS')\n\
a_hat, b_hat = res.x\n\
a_hat, b_hat, round(a_hat), round(b_hat) #А,B\n\
\n\
#---------------------------------------------------------------\n\
\n\
class distr(rv_continuous):\n\
def _pdf(self, x):\n\
    if 0 <= x <= 1:\n\
        return round(a_hat) * round(b_hat) * x ** (round(a_hat) - 1) * (1 - x ** round(a_hat)) ** (round(b_hat) - 1)\n\
    return 0\n\
\n\
#----------------------------------------------------------------\n\
\n\
X = distr()\n\
\n\
#---------------------------------------------------------------\n\
\n\
integrate.quad(lambda x: x * f(x, round(a_hat), round(b_hat)), 0, 1) #1 занчение - мат ожидание\n\
\n\
#---------------------------------------------------------------\n\
\n\
current = 0\n\
\n\
prec = 15\n\
p = 0\n\
\n\
d = 1\n\
\n\
while p < prec:\n\
if X.cdf(current) <= quantil:\n\
    current += d\n\
else:\n\
    current -= d\n\
    d /= 10\n\
    p += 1\n\
\n\
current #квантиль"
        ,
        "test4":"Пусть x⃗ =(x1,…,x30)\n\
– реализация случайной выборки X⃗ =(X1,…,X30) из нормального распределения N(μ;3,42)\n\
. Проверяется на уровне значимости α=0,01 основная гипотеза H0:μ=1,29\n\
против альтернативной гипотезы H1:μ≠1,29 с критическим множеством вида Kα=(−∞,−A)∪(A,+∞)\n\
. 1) Найдите значение статистики критерия Zнабл.=Z(x⃗ ). 2) Найдите границу А критического множества. 3) Найдите P\n\
-значение критерия и сделайте выводы. 4) Найдите мощность Wкритерия для H1:μ=1,17.Исходные данные: x⃗ =\n\
(1,416; 0,624; 6,471; 6,256; 1,787; 2,546; -1,758; -5,475; 0,077; 1,792; 5,443; 5,348; -0,057; 0,232;\n\
-2,305; -3,568; -4,541; 7,893; -0,473; -0,229; -3,0; 3,903; -4,227; 0,537; -1,785; 2,575; -0,477; -2,754; 1,164; 2,716).\n\
\n\
\n\
x = convert('1,416; 0,624; 6,471; 6,256; 1,787; 2,546; -1,758; -5,475; 0,077; 1,792; 5,443; 5,348; -0,057; 0,232; -2,305; -3,568; -4,541; 7,893; -0,473; -0,229; -3,0; 3,903; -4,227; 0,537; -1,785; 2,575; -0,477; -2,754; 1,164; 2,716')\n\
x = np.array(x)\n\
n = len(x)\n\
\n\
s = 3.4\n\
alpha = 0.01\n\
mu0 = 1.29\n\
mu1 = 1.17\n\
\n\
#---------------------------------------------------------------\n\
\n\
z = np.sqrt(n) * (x.mean() - mu0) / s\n\
rrstr(z,3)\n\
\n\
#---------------------------------------------------------------\n\
\n\
A = Z.isf(alpha / 2)\n\
rrstr(A,3)\n\
\n\
#---------------------------------------------------------------\n\
\n\
P = 2 * min(Z.cdf(z), Z.sf(z))\n\
rrstr(P,3)\n\
\n\
#---------------------------------------------------------------\n\
\n\
beta = Phi0(A - np.sqrt(n) * (mu1 - mu0) / s) + Phi0(A + np.sqrt(n) * (mu1 - mu0) / s)\n\
W = 1 - beta\n\
rrstr(W,3)\n\
\n\
#-------------------------------------------------------------------------------------------------------------------------------------------------------------\n\
\n\
Пусть x⃗ =(x1,…,x20)– реализация случайной выборки X⃗ =(X1,…,X20)\n\
из нормального распределения N(μ;σ2). Проверяется на уровне значимости α=0,05\n\
основная гипотеза H0:μ=1,10 против альтернативной гипотезы H1:μ≠1,10\n\
с критическим множеством вида Kα=(−∞,−A)∪(A,+∞). 1) Найдите значение статистики критерия t=Tнабл.=T(x⃗ )\n\
. 2) Найдите границу А критического множества. 3) Найдите P-значение критерия и сделайте выводы. 4) Найдите мощность W\n\
критерия для H1:μ=0,91.\n\
Исходные данные: x⃗ =\n\
(1,146; 2,958; -3,325; -0,534; 0,374; 5,293; 0,12; 1,185; 5,148; 5,351; 2,639; 1,47; -1,967; 4,96; 6,057; -0,542; 1,544; -0,243; -1,988; 2,844).\n\
\n\
#---------------------------------------------------------------\n\
\n\
x = convert('1,146; 2,958; -3,325; -0,534; 0,374; 5,293; 0,12; 1,185; 5,148; 5,351; 2,639; 1,47; -1,967; 4,96; 6,057; -0,542; 1,544; -0,243; -1,988; 2,844')\n\
x = np.array(x)\n\
n = len(x)\n\
\n\
alpha = 0.05\n\
mu0 = 1.1\n\
mu1 = 0.91\n\
\n\
#---------------------------------------------------------------\n\
\n\
T = np.sqrt(n - 1) * (x.mean() - mu0) / x.std(ddof=0)\n\
rrstr(T,3)\n\
\n\
#---------------------------------------------------------------\n\
\n\
A = t(n - 1).isf(alpha / 2)\n\
rrstr(A,3)\n\
\n\
#---------------------------------------------------------------\n\
\n\
P = 2 * min(t(n - 1).cdf(T), t(n - 1).sf(T))\n\
rrstr(P,3)\n\
\n\
#---------------------------------------------------------------\n\
\n\
delta = np.sqrt(n - 1) * (mu1 - mu0) / x.std()\n\
t2 = t(n - 1).isf(alpha / 2)\n\
\n\
beta = nct(n - 1, delta).cdf(t2) - nct(n - 1, delta).cdf(-t2)\n\
W = 1 - beta\n\
rrstr(W,3)\n\
\n\
#------------------------------------------------------------------------------------------------------------------------------------------------------------\n\
\n\
Пусть x⃗ =(x1,…,x30)– реализация случайной выборки X⃗ =(X1,…,X30)\n\
из нормального распределения N(1,18;σ2). Проверяется на уровне значимости α=0,02\n\
гипотеза H0:σ=1,14 против альтернативной гипотезы H1:σ≠1,14\n\
с критическим множеством вида Kα=(0;A)∪(B;+∞). 1) Найдите значение статистики критерия χ20.\n\
2) Найдите границы А и В критического множества и проверьте гипотезу H0. 3) Найдите P\n\
-значение критерия. 4) Найдите вероятность ошибки второго рода β для σ1=1,24. Исходные данные: x⃗ =\n\
(0,889; 1,514; 2,846; 2,811; 0,84; 0,945; 0,02; -0,441; -0,796; 3,739; 0,688; 0,777; -0,233; 2,284; -0,681; 1,056; 0,21;\n\
1,8; 0,687; -0,144; 1,285; 1,851; 1,402; 1,695; 0,533; 0,87; 0,486; 0,874; 0,312; -0,821).\n\
\n\
\n\
#---------------------------------------------------------------\n\
\n\
x = convert('0,889; 1,514; 2,846; 2,811; 0,84; 0,945; 0,02; -0,441; -0,796; 3,739; 0,688; 0,777; -0,233; 2,284; -0,681; 1,056; 0,21; 1,8; 0,687; -0,144; 1,285; 1,851; 1,402; 1,695; 0,533; 0,87; 0,486; 0,874; 0,312; -0,821')\n\
x = np.array(x)\n\
n = len(x)\n\
\n\
alpha = 0.02\n\
mu = 1.18\n\
s0 = 1.14\n\
s1 = 1.24\n\
\n\
#---------------------------------------------------------------\n\
\n\
s2 = np.sum((x - mu) ** 2) / n\n\
\n\
CHI = n * s2 / s0 ** 2\n\
rrstr(CHI,3)\n\
\n\
#---------------------------------------------------------------\n\
\n\
A = chi2(n).isf(1 - alpha / 2)\n\
B = chi2(n).isf(alpha / 2)\n\
rrstr(A,3)\n\
\n\
#---------------------------------------------------------------\n\
\n\
rrstr(B,3)\n\
\n\
#---------------------------------------------------------------\n\
\n\
P = 2 * min(chi2(n).cdf(CHI), chi2(n).sf(CHI))\n\
rrstr(P,3)\n\
\n\
#---------------------------------------------------------------\n\
\n\
beta = chi2(n).cdf(s0 ** 2 / s1 ** 2 * B) - chi2(n).cdf(s0 ** 2 / s1 ** 2 * A)\n\
rrstr(beta, 3)\n\
\n\
#---------------------------------------------------------------------------------------------------------------------------------------------------------------------------\n\
\n\
Пусть x⃗ =(x1,…,x30)– реализация случайной выборки X⃗ =(X1,…,X30)\n\
из нормального распределения N(μ;σ2). Проверяется на уровне значимости α=0,02гипотеза H0:σ=1,14\n\
против альтернативной гипотезы H1:σ≠1,14с критическим множеством вида Kα=(0;A)∪(B;+∞).\n\
1) Найдите значение статистики критерия χ2. 2) Найдите границы А и В критического множества и проверьте гипотезу H0.\n\
3) Найдите P-значение критерия. 4) Найдите вероятность ошибки второго рода βдля σ1=1,24.\n\
Исходные данные: x⃗ =\n\
(0,889; 1,514; 2,846; 2,811; 0,84; 0,945; 0,02; -0,441; -0,796; 3,739; 0,688; 0,777; -0,233; 2,284; -0,681; 1,056;\n\
0,21; 1,8; 0,687; -0,144; 1,285; 1,851; 1,402; 1,695; 0,533; 0,87; 0,486; 0,874; 0,312; -0,821).\n\
\n\
\n\
#---------------------------------------------------------------\n\
\n\
x = convert('0,889; 1,514; 2,846; 2,811; 0,84; 0,945; 0,02; -0,441; -0,796; 3,739; 0,688; 0,777; -0,233; 2,284; -0,681; 1,056; 0,21; 1,8; 0,687; -0,144; 1,285; 1,851; 1,402; 1,695; 0,533; 0,87; 0,486; 0,874; 0,312; -0,821')\n\
x = np.array(x)\n\
n = len(x)\n\
\n\
alpha = 0.02\n\
s0 = 1.14\n\
s1 = 1.24\n\
\n\
#---------------------------------------------------------------\n\
\n\
CHI = (n - 1) * x.var(ddof=1) / s0 ** 2\n\
rrstr(CHI,3)\n\
\n\
#---------------------------------------------------------------\n\
\n\
A = chi2(n - 1).isf(1 - alpha / 2)\n\
B = chi2(n - 1).isf(alpha / 2)\n\
rrstr(A,3)\n\
\n\
#---------------------------------------------------------------\n\
\n\
rrstr(B,3)\n\
\n\
#---------------------------------------------------------------\n\
\n\
P = 2 * min(chi2(n - 1).cdf(CHI), chi2(n - 1).sf(CHI))\n\
rrstr(P,3)\n\
\n\
#---------------------------------------------------------------\n\
\n\
beta = chi2(n - 1).cdf(s0 ** 2 / s1 ** 2 * B) - chi2(n - 1).cdf(s0 ** 2 / s1 ** 2 * A)\n\
rrstr(beta,3)\n\
\n\
#-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------\n\
\n\
Пусть x⃗ =(x1,…,x25)– реализация случайной выборки X⃗ =(X1,…,X25)из нормального распределения N(μx;0,72)\n\
, а y⃗ =(y1,…,y30) – реализация случайной выборки Y⃗ =(Y1,…,Y30)из нормального распределения N(μy;1,42).\n\
Известно, что X⃗ и Y⃗ независимы. Проверяется гипотеза H0:μx=μy против альтернативной гипотезы H1:μx>μy.\n\
При уровне значимости α применяется критерий с критической областью {Z>A}, где статистика критерия Z=Z(X⃗ ,Y⃗ )\n\
– это нормированная разность X¯−Y¯, A=Aα – зависящее от α критическое значение. Соответствующее критическое множество имеет вид Kα=(Aα;∞).\n\
1) Найдите значение статистики критерия Zнабл.=Z(x⃗ ,y⃗ ).\n\
2) Найдите P-значение критерия. 3) Найдите критическое значение A, критическое множество Kα и проверьте гипотезу H0при α=0,02.\n\
4) Найдите мощность критерия W в случае μx−μy=0,1 и α=0,02.\n\
Исходные данные: x⃗ =\n\
(3,842; 3,374; 4,18; 4,5; 4,247; 4,412; 3,756; 3,946; 3,729; 3,948; 3,631; 2,992; 4,324; 3,919; 3,059; 4,524; 3,565; 4,236; 4,71; 4,29; 4,998; 3,336; 4,482; 3,721; 3,59); y⃗ =\n\
(3,19; 3,564; 4,079; 2,369; 5,261; 4,652; 1,849; 6,084; 6,654; 5,65; 3,748; 2,501; 5,476; 3,436; 5,711; 4,292; 5,367; 4,499; 4,989; 4,015; 6,5; 4,178; 4,563; 6,636; 2,113; 2,221; 5,357; 2,358; 6,721; 3,421).\n\
\n\
\n\
#---------------------------------------------------------------\n\
\n\
x = convert('3,842; 3,374; 4,18; 4,5; 4,247; 4,412; 3,756; 3,946; 3,729; 3,948; 3,631; 2,992; 4,324; 3,919; 3,059; 4,524; 3,565; 4,236; 4,71; 4,29; 4,998; 3,336; 4,482; 3,721; 3,59')\n\
x = np.array(x)\n\
n = len(x)\n\
\n\
y = convert('3,19; 3,564; 4,079; 2,369; 5,261; 4,652; 1,849; 6,084; 6,654; 5,65; 3,748; 2,501; 5,476; 3,436; 5,711; 4,292; 5,367; 4,499; 4,989; 4,015; 6,5; 4,178; 4,563; 6,636; 2,113; 2,221; 5,357; 2,358; 6,721; 3,421')\n\
y = np.array(y)\n\
m = len(y)\n\
\n\
sx = 0.7\n\
sy = 1.4\n\
alpha = 0.02\n\
delta = 0.1\n\
\n\
#---------------------------------------------------------------\n\
\n\
z = (x.mean() - y.mean()) / np.sqrt(sx ** 2 / n + sy ** 2 / m)\n\
rrstr(z,3)\n\
\n\
#---------------------------------------------------------------\n\
\n\
P = Z.sf(z)\n\
rrstr(P,3)\n\
\n\
#---------------------------------------------------------------\n\
\n\
A = Z.isf(alpha)\n\
rrstr(A,3)\n\
\n\
#---------------------------------------------------------------\n\
\n\
beta = 1 / 2 + Phi0(A - np.sqrt(m * n) / np.sqrt(m * sx ** 2 + n * sy ** 2) * delta)\n\
W = 1 - beta\n\
rrstr(W,3)\n\
\n\
#-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------\n\
\n\
Для трех групп финансовых показателей A: (X1;...;X27), B: (Y1;...;Y33), C: (Z1;...;Z39),\n\
которые по предположению независимы и распределены, соответственно, по трем нормальным законам N(μx,σ2), N(μy,σ2), N(μz,σ2)\n\
(с одинаковой неизвестной дисперсией σ2) на уровне значимости α=0,01 с помощью F-критерия (Фишера) проверяется гипотеза H0:μx=μy=μz\n\
о совпадении ожидаемых значений показателей. Конкретные значения всех показателей указаны ниже. 1) По данным значениям показателей найдите межгрупповую дисперсию.\n\
2) По этим же данным найдите среднюю групповую дисперсию. 3) Найдите значение статистики F-критерия, критическое множество Kα и проверьте гипотезу H0.\n\
4) Найдите P -значение критерия и сделайте выводы.Значения показателей группы A:\n\
(0,616; 1,046; 2,575; -0,344; 2,339; -0,68; 3,739; 2,251; -1,252; 3,536; -0,491; 5,556; 4,856; -1,68; 2,33; 1,345; 2,829; 2,539; 3,304; 3,497; 0,211; 3,563;\n\
0,94; 3,642; 1,956; 3,919; 3,568). Значения показателей группы B: (2,834; 1,504; -0,678; 5,619; 0,97; 1,617; 3,768; -1,309; 3,343; -1,778; -0,854; 1,04; 2,83;\n\
-2,335; 4,853; 5,6; 4,341; 4,362; 3,52; 1,151; -0,621; -2,88; 1,697; 1,753; 0,211; 2,157;1,989; 2,457; 1,399; 1,61; -0,558; 2,132; 2,293). Значения показателей группы\n\
C: (2,398;-2,77; 4,679; 1,924; 0,574; 5,329; 0,699; 4,457; -0,3; 1,682; -1,34; 0,046; -1,096; 1,935; 2,411; 4,134; 5,643; 3,071; 6,526; 4,941; 2,844; -0,43;\n\
-2,066; 0,22; 0,317; -1,923; 1,38; -2,485; 0,111; -0,542; 4,78; 1,93; 0,462; 5,487; -3,547; 2,933; -0,987; -0,21; 3,955).\n\
\n\
#---------------------------------------------------------------\n\
\n\
x = convert('0,616; 1,046; 2,575; -0,344; 2,339; -0,68; 3,739; 2,251; -1,252; 3,536; -0,491; 5,556; 4,856; -1,68; 2,33; 1,345; 2,829; 2,539; 3,304; 3,497; 0,211; 3,563; 0,94; 3,642; 1,956; 3,919; 3,568')\n\
x = np.array(x)\n\
n1 = len(x)\n\
\n\
y = convert('2,834; 1,504; -0,678; 5,619; 0,97; 1,617; 3,768; -1,309; 3,343; -1,778; -0,854; 1,04; 2,83; -2,335; 4,853; 5,6; 4,341; 4,362; 3,52; 1,151; -0,621; -2,88; 1,697; 1,753; 0,211; 2,157; 1,989; 2,457; 1,399; 1,61; -0,558; 2,132; 2,293')\n\
y = np.array(y)\n\
n2 = len(y)\n\
\n\
z = convert('2,398; -2,77; 4,679; 1,924; 0,574; 5,329; 0,699; 4,457; -0,3; 1,682; -1,34; 0,046; -1,096; 1,935; 2,411; 4,134; 5,643; 3,071; 6,526; 4,941; 2,844; -0,43; -2,066; 0,22; 0,317; -1,923; 1,38; -2,485; 0,111; -0,542; 4,78; 1,93; 0,462; 5,487; -3,547; 2,933; -0,987; -0,21; 3,955')\n\
z = np.array(z)\n\
n3 = len(z)\n\
\n\
xyz = pd.DataFrame([x, y, z]).T\n\
xyz_all = np.concatenate([x, y, z])\n\
n = [n1, n2, n3]\n\
N = sum(n)\n\
k = 3\n\
\n\
alpha = 0.01\n\
\n\
#---------------------------------------------------------------\n\
\n\
d2 = np.sum((xyz.mean() - xyz_all.mean()) ** 2 * n) / N\n\
rrstr(d2,3)\n\
\n\
#---------------------------------------------------------------\n\
\n\
meanvar = np.sum(xyz.var(ddof=0) * n) / N\n\
rrstr(meanvar,3)\n\
\n\
#---------------------------------------------------------------\n\
\n\
# проверка\n\
(d2 + meanvar), xyz_all.var(ddof=0)\n\
\n\
#---------------------------------------------------------------\n\
\n\
SSE = N * meanvar\n\
MSE = SSE / (N - k)\n\
SSTR = N * d2\n\
MSTR = SSTR / (k - 1)\n\
F = MSTR / MSE\n\
rrstr(F,3)\n\
\n\
#---------------------------------------------------------------\n\
\n\
f(k - 1, N - k).isf(alpha)\n\
\n\
#---------------------------------------------------------------\n\
\n\
P = f(k - 1, N - k).sf(F)\n\
rrstr(P,3)"

                }
    print(sklad[number])


    # Определяем путь к изображению
    image_path_2 = os.path.join(main_path, f"resh_{number}.png")

    # Открываем изображение
    img2 = Image.open(image_path_2)

    # Отображаем изображение
    display(img2)




from setuptools import setup, find_packages
from io import open

classifiers = [
    'Development Status :: 5 - Production/Stable',
    'Intended Audience :: Education',
    'Operating System :: Microsoft :: Windows :: Windows 10',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 3'
]

setup(
    name='tvms',
    version='0.0.27',
    description='Aboubakar',
    long_description=open('README.txt').read()+'\n\n'+open('CHANGELOG.txt').read(),
    url='',
    author='Boo4kin',
    author_email='bkolyabi@gmail.com',
    classifiers=classifiers,
    license='MIT',
    keywords='test',
    include_package_data=True,  # Include data files specified in MANIFEST.in
    package_data={
        '': ['pic/*.jpeg'],  # Include all PNG files in the 'pic' directory
    },
    install_requiers=[''],
    packages= ['tvms']

)
